# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`zabbix`](#zabbix): This will install and configure the zabbix-server on a single host.
* [`zabbix::agent`](#zabbix--agent): This will install and configure the zabbix-agent deamon
* [`zabbix::database`](#zabbix--database): This will install the correct database and one or more users for correct usage
* [`zabbix::database::sqlite`](#zabbix--database--sqlite): Class to handle sqlite database installations zabbix will automatically create a sqlite schema if one does not already exist.
* [`zabbix::javagateway`](#zabbix--javagateway): This will install and configure the zabbix-agent deamon
* [`zabbix::params`](#zabbix--params): This class manages zabbix server parameters
* [`zabbix::proxy`](#zabbix--proxy): This will install and configure the zabbix-proxy deamon
* [`zabbix::repo`](#zabbix--repo): If enabled, this will install the repository used for installing zabbix
* [`zabbix::resources::agent`](#zabbix--resources--agent): This will create resources into puppetdb for automatically configuring agent into zabbix front-end.
* [`zabbix::resources::proxy`](#zabbix--resources--proxy): This will create resources into puppetdb for automatically configuring proxy agent into zabbix front-end.
* [`zabbix::resources::web`](#zabbix--resources--web): This will load all zabbix related items from the puppet database and uses the zabbixapi gem to add/configure hosts via the zabbix-api
* [`zabbix::sender`](#zabbix--sender): This will install and configure the zabbix-agent deamon
* [`zabbix::server`](#zabbix--server): This will install and configure the zabbix-server deamon
* [`zabbix::userparameter`](#zabbix--userparameter): This class can be used when you use hiera or The Foreman. With this tools you can't use and define. This make use of "create_resources".
* [`zabbix::web`](#zabbix--web): This will install the zabbix-web package and install an virtual host.
* [`zabbix::zabbixapi`](#zabbix--zabbixapi): This will install the zabbixapi gem.
* [`zabbix::zapache`](#zabbix--zapache): This will install and configure the zapache monitoring script Upstream: https://github.com/lorf/zapache

#### Private Classes

* `zabbix::database::mysql`: This will install and load the sql files for the tables and other data which is needed for zabbix.
* `zabbix::database::postgresql`: This will install and load the sql files for the tables and other data which is needed for zabbix.

### Defined types

* [`zabbix::resources::template`](#zabbix--resources--template): This will create resources into puppetdb for automatically configuring agent into zabbix front-end.
* [`zabbix::resources::userparameters`](#zabbix--resources--userparameters): This will create resources into puppetdb for automatically configuring agent into zabbix front-end.
* [`zabbix::startup`](#zabbix--startup): This manage the zabbix related service startup script.
* [`zabbix::template`](#zabbix--template): This will upload an Zabbix Template (XML format)
* [`zabbix::userparameters`](#zabbix--userparameters): This will install an userparameters file with keys for items that can be checked with zabbix.

### Resource types

* [`zabbix_application`](#zabbix_application): Manage zabbix applications  Example:   zabbix_application{"app1":     ensure   => present,     template => 'template1',   } It Raise exceptio
* [`zabbix_host`](#zabbix_host): Manage zabbix hosts
* [`zabbix_hostgroup`](#zabbix_hostgroup): Manage zabbix hostgroups
* [`zabbix_proxy`](#zabbix_proxy): Manage zabbix proxies
* [`zabbix_template`](#zabbix_template): Manage zabbix templates
* [`zabbix_template_host`](#zabbix_template_host): Link or Unlink template to host. Only for Zabbix < 6.0!  Example:   zabbix_template_host{ 'mysql_template@db1':     ensure => present,   } Na
* [`zabbix_userparameters`](#zabbix_userparameters): Manage zabbix user templates

### Data types

* [`Zabbix::Databases`](#Zabbix--Databases): Type for supported databases by the zabbix module
* [`Zabbix::Historyics`](#Zabbix--Historyics): Type for size values in bytes (also allows k/K and m/M as appendix)

## Classes

### <a name="zabbix"></a>`zabbix`

This will install and configure the zabbix-server on a single host.

#### Examples

##### Single host setup:

```puppet
class { 'zabbix':
  zabbix_url => 'zabbix.dj-wasabi.nl',
}
```

##### This assumes that you want to use the postgresql database. If not and you want to supply your own database crendentials:

```puppet
class { 'zabbix':
  zabbix_url        => 'zabbix.dj-wasabi.nl',
  database_type     => 'mysql',
  database_user     => 'zabbix',
  database_password => 'ThisIsVeryDifficult.nl',
}
```

#### Parameters

The following parameters are available in the `zabbix` class:

* [`zabbix_url`](#-zabbix--zabbix_url)
* [`zabbix_version`](#-zabbix--zabbix_version)
* [`zabbix_timezone`](#-zabbix--zabbix_timezone)
* [`zabbix_template_dir`](#-zabbix--zabbix_template_dir)
* [`zabbix_package_state`](#-zabbix--zabbix_package_state)
* [`zabbix_server`](#-zabbix--zabbix_server)
* [`zabbix_server_ip`](#-zabbix--zabbix_server_ip)
* [`zabbix_web`](#-zabbix--zabbix_web)
* [`zabbix_web_ip`](#-zabbix--zabbix_web_ip)
* [`database_type`](#-zabbix--database_type)
* [`database_path`](#-zabbix--database_path)
* [`manage_database`](#-zabbix--manage_database)
* [`manage_repo`](#-zabbix--manage_repo)
* [`manage_firewall`](#-zabbix--manage_firewall)
* [`manage_service`](#-zabbix--manage_service)
* [`manage_resources`](#-zabbix--manage_resources)
* [`manage_vhost`](#-zabbix--manage_vhost)
* [`default_vhost`](#-zabbix--default_vhost)
* [`apache_use_ssl`](#-zabbix--apache_use_ssl)
* [`apache_ssl_cert`](#-zabbix--apache_ssl_cert)
* [`apache_ssl_key`](#-zabbix--apache_ssl_key)
* [`apache_ssl_cipher`](#-zabbix--apache_ssl_cipher)
* [`apache_ssl_chain`](#-zabbix--apache_ssl_chain)
* [`apache_listen_ip`](#-zabbix--apache_listen_ip)
* [`apache_listenport`](#-zabbix--apache_listenport)
* [`apache_listenport_ssl`](#-zabbix--apache_listenport_ssl)
* [`apache_php_max_execution_time`](#-zabbix--apache_php_max_execution_time)
* [`apache_php_memory_limit`](#-zabbix--apache_php_memory_limit)
* [`apache_php_post_max_size`](#-zabbix--apache_php_post_max_size)
* [`apache_php_upload_max_filesize`](#-zabbix--apache_php_upload_max_filesize)
* [`apache_php_max_input_time`](#-zabbix--apache_php_max_input_time)
* [`apache_php_always_populate_raw_post_data`](#-zabbix--apache_php_always_populate_raw_post_data)
* [`ldap_cacert`](#-zabbix--ldap_cacert)
* [`ldap_clientcert`](#-zabbix--ldap_clientcert)
* [`ldap_clientkey`](#-zabbix--ldap_clientkey)
* [`ldap_reqcert`](#-zabbix--ldap_reqcert)
* [`zabbix_api_user`](#-zabbix--zabbix_api_user)
* [`zabbix_api_pass`](#-zabbix--zabbix_api_pass)
* [`zabbix_api_access`](#-zabbix--zabbix_api_access)
* [`listenport`](#-zabbix--listenport)
* [`sourceip`](#-zabbix--sourceip)
* [`logfile`](#-zabbix--logfile)
* [`logfilesize`](#-zabbix--logfilesize)
* [`logtype`](#-zabbix--logtype)
* [`debuglevel`](#-zabbix--debuglevel)
* [`pidfile`](#-zabbix--pidfile)
* [`database_host`](#-zabbix--database_host)
* [`database_name`](#-zabbix--database_name)
* [`database_schema`](#-zabbix--database_schema)
* [`database_double_ieee754`](#-zabbix--database_double_ieee754)
* [`database_user`](#-zabbix--database_user)
* [`database_password`](#-zabbix--database_password)
* [`database_socket`](#-zabbix--database_socket)
* [`database_port`](#-zabbix--database_port)
* [`database_charset`](#-zabbix--database_charset)
* [`database_collate`](#-zabbix--database_collate)
* [`database_tablespace`](#-zabbix--database_tablespace)
* [`database_tlsconnect`](#-zabbix--database_tlsconnect)
* [`database_tlscafile`](#-zabbix--database_tlscafile)
* [`startpollers`](#-zabbix--startpollers)
* [`startpreprocessors`](#-zabbix--startpreprocessors)
* [`startipmipollers`](#-zabbix--startipmipollers)
* [`startodbcpollers`](#-zabbix--startodbcpollers)
* [`startpollersunreachable`](#-zabbix--startpollersunreachable)
* [`starttrappers`](#-zabbix--starttrappers)
* [`startpingers`](#-zabbix--startpingers)
* [`startalerters`](#-zabbix--startalerters)
* [`startdiscoverers`](#-zabbix--startdiscoverers)
* [`startescalators`](#-zabbix--startescalators)
* [`starthttppollers`](#-zabbix--starthttppollers)
* [`starttimers`](#-zabbix--starttimers)
* [`javagateway`](#-zabbix--javagateway)
* [`javagatewayport`](#-zabbix--javagatewayport)
* [`startjavapollers`](#-zabbix--startjavapollers)
* [`startlldprocessors`](#-zabbix--startlldprocessors)
* [`startvmwarecollectors`](#-zabbix--startvmwarecollectors)
* [`vaultdbpath`](#-zabbix--vaultdbpath)
* [`vaulttoken`](#-zabbix--vaulttoken)
* [`vaulturl`](#-zabbix--vaulturl)
* [`vmwarefrequency`](#-zabbix--vmwarefrequency)
* [`vmwarecachesize`](#-zabbix--vmwarecachesize)
* [`vmwaretimeout`](#-zabbix--vmwaretimeout)
* [`snmptrapperfile`](#-zabbix--snmptrapperfile)
* [`startsnmptrapper`](#-zabbix--startsnmptrapper)
* [`listenip`](#-zabbix--listenip)
* [`housekeepingfrequency`](#-zabbix--housekeepingfrequency)
* [`maxhousekeeperdelete`](#-zabbix--maxhousekeeperdelete)
* [`cachesize`](#-zabbix--cachesize)
* [`cacheupdatefrequency`](#-zabbix--cacheupdatefrequency)
* [`startdbsyncers`](#-zabbix--startdbsyncers)
* [`historycachesize`](#-zabbix--historycachesize)
* [`historyindexcachesize`](#-zabbix--historyindexcachesize)
* [`trendcachesize`](#-zabbix--trendcachesize)
* [`valuecachesize`](#-zabbix--valuecachesize)
* [`timeout`](#-zabbix--timeout)
* [`tlscafile`](#-zabbix--tlscafile)
* [`tlscertfile`](#-zabbix--tlscertfile)
* [`tlscrlfile`](#-zabbix--tlscrlfile)
* [`tlskeyfile`](#-zabbix--tlskeyfile)
* [`tlscipherall`](#-zabbix--tlscipherall)
* [`tlscipherall13`](#-zabbix--tlscipherall13)
* [`tlsciphercert`](#-zabbix--tlsciphercert)
* [`tlsciphercert13`](#-zabbix--tlsciphercert13)
* [`tlscipherpsk`](#-zabbix--tlscipherpsk)
* [`tlscipherpsk13`](#-zabbix--tlscipherpsk13)
* [`trappertimeout`](#-zabbix--trappertimeout)
* [`unreachableperiod`](#-zabbix--unreachableperiod)
* [`unavailabledelay`](#-zabbix--unavailabledelay)
* [`unreachabledelay`](#-zabbix--unreachabledelay)
* [`alertscriptspath`](#-zabbix--alertscriptspath)
* [`externalscripts`](#-zabbix--externalscripts)
* [`fpinglocation`](#-zabbix--fpinglocation)
* [`fping6location`](#-zabbix--fping6location)
* [`sshkeylocation`](#-zabbix--sshkeylocation)
* [`logslowqueries`](#-zabbix--logslowqueries)
* [`tmpdir`](#-zabbix--tmpdir)
* [`startproxypollers`](#-zabbix--startproxypollers)
* [`proxyconfigfrequency`](#-zabbix--proxyconfigfrequency)
* [`proxydatafrequency`](#-zabbix--proxydatafrequency)
* [`allowroot`](#-zabbix--allowroot)
* [`include_dir`](#-zabbix--include_dir)
* [`loadmodulepath`](#-zabbix--loadmodulepath)
* [`loadmodule`](#-zabbix--loadmodule)
* [`socketdir`](#-zabbix--socketdir)
* [`manage_selinux`](#-zabbix--manage_selinux)
* [`additional_service_params`](#-zabbix--additional_service_params)
* [`zabbix_user`](#-zabbix--zabbix_user)
* [`zabbix_server_name`](#-zabbix--zabbix_server_name)
* [`saml_sp_key`](#-zabbix--saml_sp_key)
* [`saml_sp_cert`](#-zabbix--saml_sp_cert)
* [`saml_idp_cert`](#-zabbix--saml_idp_cert)
* [`saml_settings`](#-zabbix--saml_settings)

##### <a name="-zabbix--zabbix_url"></a>`zabbix_url`

Data type: `Any`

Url on which zabbix needs to be available. Will create an vhost in
apache. Only needed when manage_vhost is set to true.
Example: zabbix.example.com

Default value: `''`

##### <a name="-zabbix--zabbix_version"></a>`zabbix_version`

Data type: `Any`

This is the zabbix version.

Default value: `$zabbix::params::zabbix_version`

##### <a name="-zabbix--zabbix_timezone"></a>`zabbix_timezone`

Data type: `Any`

The current timezone for vhost configuration needed for the php timezone. Example: Europe/Amsterdam

Default value: `$zabbix::params::zabbix_timezone`

##### <a name="-zabbix--zabbix_template_dir"></a>`zabbix_template_dir`

Data type: `Any`

The directory where all templates are stored before uploading via API

Default value: `$zabbix::params::zabbix_template_dir`

##### <a name="-zabbix--zabbix_package_state"></a>`zabbix_package_state`

Data type: `Any`

The state of the package that needs to be installed: present or latest.

Default value: `$zabbix::params::zabbix_package_state`

##### <a name="-zabbix--zabbix_server"></a>`zabbix_server`

Data type: `Any`

This is the FQDN for the host running zabbix-server. This parameter
is used when database_type = mysql. Default: localhost

Default value: `$zabbix::params::zabbix_server`

##### <a name="-zabbix--zabbix_server_ip"></a>`zabbix_server_ip`

Data type: `Any`

This is the actual ip address of the host running zabbix-server
This parameter is used when database_type = postgresql. Default:
127.0.0.1

Default value: `$zabbix::params::zabbix_server_ip`

##### <a name="-zabbix--zabbix_web"></a>`zabbix_web`

Data type: `Any`

This is the hostname of the server which is running the
zabbix-web package. This parameter is used when database_type =
mysql. When single node: localhost

Default value: `$zabbix::params::zabbix_web`

##### <a name="-zabbix--zabbix_web_ip"></a>`zabbix_web_ip`

Data type: `Any`

This is the ip address of the server which is running the
zabbix-web package. This parameter is used when database_type =
postgresql. When single node: 127.0.0.1

Default value: `$zabbix::params::zabbix_web_ip`

##### <a name="-zabbix--database_type"></a>`database_type`

Data type: `Zabbix::Databases`

Type of database. Can use the following 2 databases:
- postgresql
- mysql

Default value: `$zabbix::params::database_type`

##### <a name="-zabbix--database_path"></a>`database_path`

Data type: `Any`

When database binaries are not found on the default path:
/bin:/usr/bin:/usr/local/sbin:/usr/local/bin
you can use this parameter to add the database_path to the above mentioned
path.

Default value: `$zabbix::params::database_path`

##### <a name="-zabbix--manage_database"></a>`manage_database`

Data type: `Any`

When true, it will configure the database and execute the sql scripts.

Default value: `$zabbix::params::manage_database`

##### <a name="-zabbix--manage_repo"></a>`manage_repo`

Data type: `Any`

When true (default) this module will manage the Zabbix repository.

Default value: `$zabbix::params::manage_repo`

##### <a name="-zabbix--manage_firewall"></a>`manage_firewall`

Data type: `Any`

When true, it will create iptables rules.

Default value: `$zabbix::params::manage_firewall`

##### <a name="-zabbix--manage_service"></a>`manage_service`

Data type: `Any`

When true, it will ensure service running and enabled.
When false, it does not care about service

Default value: `$zabbix::params::manage_service`

##### <a name="-zabbix--manage_resources"></a>`manage_resources`

Data type: `Any`

When true, it will export resources to something like puppetdb.
When set to true, you'll need to configure 'storeconfigs' to make
this happen. Default is set to false, as not everyone has this
enabled.

Default value: `$zabbix::params::manage_resources`

##### <a name="-zabbix--manage_vhost"></a>`manage_vhost`

Data type: `Any`

When true, it will create an vhost for apache. The parameter zabbix_url has to be set.

Default value: `$zabbix::params::manage_vhost`

##### <a name="-zabbix--default_vhost"></a>`default_vhost`

Data type: `Any`

When true priority of 15 is passed to zabbix vhost which would end up
with marking zabbix vhost as default one, when false priority is set to 25

Default value: `$zabbix::params::default_vhost`

##### <a name="-zabbix--apache_use_ssl"></a>`apache_use_ssl`

Data type: `Any`

Will create an ssl vhost. Also nonssl vhost will be created for redirect
nonssl to ssl vhost.

Default value: `$zabbix::params::apache_use_ssl`

##### <a name="-zabbix--apache_ssl_cert"></a>`apache_ssl_cert`

Data type: `Any`

The location of the ssl certificate file. You'll need to make sure this
file is present on the system, this module will not install this file.

Default value: `$zabbix::params::apache_ssl_cert`

##### <a name="-zabbix--apache_ssl_key"></a>`apache_ssl_key`

Data type: `Any`

The location of the ssl key file. You'll need to make sure this file is
present on the system, this module will not install this file.

Default value: `$zabbix::params::apache_ssl_key`

##### <a name="-zabbix--apache_ssl_cipher"></a>`apache_ssl_cipher`

Data type: `Any`

The ssl cipher used. Cipher is used from this website:
https://wiki.mozilla.org/Security/Server_Side_TLS

Default value: `$zabbix::params::apache_ssl_cipher`

##### <a name="-zabbix--apache_ssl_chain"></a>`apache_ssl_chain`

Data type: `Any`

The ssl chain file.

Default value: `$zabbix::params::apache_ssl_chain`

##### <a name="-zabbix--apache_listen_ip"></a>`apache_listen_ip`

Data type: `Any`

The IP the apache service should listen on.

Default value: `$zabbix::params::apache_listen_ip`

##### <a name="-zabbix--apache_listenport"></a>`apache_listenport`

Data type: `Variant[Array[Stdlib::Port], Stdlib::Port]`

The port for the apache vhost.

Default value: `$zabbix::params::apache_listenport`

##### <a name="-zabbix--apache_listenport_ssl"></a>`apache_listenport_ssl`

Data type: `Variant[Array[Stdlib::Port], Stdlib::Port]`

The port for the apache SSL vhost.

Default value: `$zabbix::params::apache_listenport_ssl`

##### <a name="-zabbix--apache_php_max_execution_time"></a>`apache_php_max_execution_time`

Data type: `Any`

Max execution time for php. Default: 300

Default value: `$zabbix::params::apache_php_max_execution_time`

##### <a name="-zabbix--apache_php_memory_limit"></a>`apache_php_memory_limit`

Data type: `Any`

PHP memory size limit. Default: 128M

Default value: `$zabbix::params::apache_php_memory_limit`

##### <a name="-zabbix--apache_php_post_max_size"></a>`apache_php_post_max_size`

Data type: `Any`

PHP maximum post size data. Default: 16M

Default value: `$zabbix::params::apache_php_post_max_size`

##### <a name="-zabbix--apache_php_upload_max_filesize"></a>`apache_php_upload_max_filesize`

Data type: `Any`

PHP maximum upload filesize. Default: 2M

Default value: `$zabbix::params::apache_php_upload_max_filesize`

##### <a name="-zabbix--apache_php_max_input_time"></a>`apache_php_max_input_time`

Data type: `Any`

Max input time for php. Default: 300

Default value: `$zabbix::params::apache_php_max_input_time`

##### <a name="-zabbix--apache_php_always_populate_raw_post_data"></a>`apache_php_always_populate_raw_post_data`

Data type: `Any`

Default: -1

Default value: `$zabbix::params::apache_php_always_populate_raw_post_data`

##### <a name="-zabbix--ldap_cacert"></a>`ldap_cacert`

Data type: `Optional[Stdlib::Absolutepath]`

Set location of ca_cert used by LDAP authentication.

Default value: `$zabbix::params::ldap_cacert`

##### <a name="-zabbix--ldap_clientcert"></a>`ldap_clientcert`

Data type: `Optional[Stdlib::Absolutepath]`

Set location of client cert used by LDAP authentication.

Default value: `$zabbix::params::ldap_clientcert`

##### <a name="-zabbix--ldap_clientkey"></a>`ldap_clientkey`

Data type: `Optional[Stdlib::Absolutepath]`

Set location of client key used by LDAP authentication.

Default value: `$zabbix::params::ldap_clientkey`

##### <a name="-zabbix--ldap_reqcert"></a>`ldap_reqcert`

Data type: `Optional[Enum['never', 'allow', 'try', 'demand', 'hard']]`

Specifies what checks to perform on a server certificate

Default value: `$zabbix::params::ldap_reqcert`

##### <a name="-zabbix--zabbix_api_user"></a>`zabbix_api_user`

Data type: `Any`

Name of the user which the api should connect to. Default: Admin

Default value: `$zabbix::params::server_api_user`

##### <a name="-zabbix--zabbix_api_pass"></a>`zabbix_api_pass`

Data type: `Any`

Password of the user which connects to the api. Default: zabbix

Default value: `$zabbix::params::server_api_pass`

##### <a name="-zabbix--zabbix_api_access"></a>`zabbix_api_access`

Data type: `Optional[Array[Stdlib::Host,1]]`

Which host has access to the api. Default: no restriction

Default value: `$zabbix::params::server_api_access`

##### <a name="-zabbix--listenport"></a>`listenport`

Data type: `Any`

Listen port for the zabbix-server. Default: 10051

Default value: `$zabbix::params::server_listenport`

##### <a name="-zabbix--sourceip"></a>`sourceip`

Data type: `Any`

Source ip address for outgoing connections.

Default value: `$zabbix::params::server_sourceip`

##### <a name="-zabbix--logfile"></a>`logfile`

Data type: `Optional[Stdlib::Absolutepath]`

Name of log file.

Default value: `$zabbix::params::server_logfile`

##### <a name="-zabbix--logfilesize"></a>`logfilesize`

Data type: `Any`

Maximum size of log file in MB.

Default value: `$zabbix::params::server_logfilesize`

##### <a name="-zabbix--logtype"></a>`logtype`

Data type: `Enum['console', 'file', 'system']`

Specifies where log messages are written to. (options: console, file, system)

Default value: `$zabbix::params::server_logtype`

##### <a name="-zabbix--debuglevel"></a>`debuglevel`

Data type: `Any`

Specifies debug level.

Default value: `$zabbix::params::server_debuglevel`

##### <a name="-zabbix--pidfile"></a>`pidfile`

Data type: `Any`

Name of pid file.

Default value: `$zabbix::params::server_pidfile`

##### <a name="-zabbix--database_host"></a>`database_host`

Data type: `Any`

Database host name.

Default value: `$zabbix::params::server_database_host`

##### <a name="-zabbix--database_name"></a>`database_name`

Data type: `Any`

Database name.

Default value: `$zabbix::params::server_database_name`

##### <a name="-zabbix--database_schema"></a>`database_schema`

Data type: `Any`

Schema name. used for ibm db2.

Default value: `$zabbix::params::server_database_schema`

##### <a name="-zabbix--database_double_ieee754"></a>`database_double_ieee754`

Data type: `Boolean`

Enable extended range of float values for new installs of Zabbix >= 5.0 and
after patching upgraded installs to 5.0 or greater.
https://www.zabbix.com/documentation/5.0/manual/installation/upgrade_notes_500#enabling_extended_range_of_numeric_float_values

Default value: `$zabbix::params::server_database_double_ieee754`

##### <a name="-zabbix--database_user"></a>`database_user`

Data type: `Any`

Database user. ignored for sqlite.

Default value: `$zabbix::params::server_database_user`

##### <a name="-zabbix--database_password"></a>`database_password`

Data type: `Any`

Database password. ignored for sqlite.

Default value: `$zabbix::params::server_database_password`

##### <a name="-zabbix--database_socket"></a>`database_socket`

Data type: `Any`

Path to mysql socket.

Default value: `$zabbix::params::server_database_socket`

##### <a name="-zabbix--database_port"></a>`database_port`

Data type: `Any`

Database port when not using local socket. Ignored for sqlite.

Default value: `$zabbix::params::server_database_port`

##### <a name="-zabbix--database_charset"></a>`database_charset`

Data type: `Any`

The default charset of the database.

Default value: `$zabbix::params::server_database_charset`

##### <a name="-zabbix--database_collate"></a>`database_collate`

Data type: `Any`

The default collation of the database.

Default value: `$zabbix::params::server_database_collate`

##### <a name="-zabbix--database_tablespace"></a>`database_tablespace`

Data type: `Any`

The tablespace the database will be created in. This setting only affects PostgreSQL databases.

Default value: `$zabbix::params::server_database_tablespace`

##### <a name="-zabbix--database_tlsconnect"></a>`database_tlsconnect`

Data type: `Optional[Enum['required', 'verify_ca', 'verify_full']]`

Available options:
* required - connect using TLS
* verify_ca - connect using TLS and verify certificate
* verify_full - connect using TLS, verify certificate and verify that database identity specified by DBHost matches its certificate

Default value: `$zabbix::params::server_database_tlsconnect`

##### <a name="-zabbix--database_tlscafile"></a>`database_tlscafile`

Data type: `Optional[Stdlib::Absolutepath]`

Full pathname of a file containing the top-level CA(s) certificates for database certificate verification.

Default value: `$zabbix::params::server_database_tlscafile`

##### <a name="-zabbix--startpollers"></a>`startpollers`

Data type: `Any`

Number of pre-forked instances of pollers.

Default value: `$zabbix::params::server_startpollers`

##### <a name="-zabbix--startpreprocessors"></a>`startpreprocessors`

Data type: `Integer[1, 1000]`

Number of pre-forked instances of preprocessing workers

Default value: `$zabbix::params::server_startpreprocessors`

##### <a name="-zabbix--startipmipollers"></a>`startipmipollers`

Data type: `Any`

Number of pre-forked instances of ipmi pollers.

Default value: `$zabbix::params::server_startipmipollers`

##### <a name="-zabbix--startodbcpollers"></a>`startodbcpollers`

Data type: `Integer[0, 1000]`

Number of pre-forked instances of ODBC pollers.

Default value: `$zabbix::params::server_startodbcpollers`

##### <a name="-zabbix--startpollersunreachable"></a>`startpollersunreachable`

Data type: `Any`

Number of pre-forked instances of pollers for unreachable hosts (including ipmi).

Default value: `$zabbix::params::server_startpollersunreachable`

##### <a name="-zabbix--starttrappers"></a>`starttrappers`

Data type: `Any`

Number of pre-forked instances of trappers.

Default value: `$zabbix::params::server_starttrappers`

##### <a name="-zabbix--startpingers"></a>`startpingers`

Data type: `Any`

Number of pre-forked instances of icmp pingers.

Default value: `$zabbix::params::server_startpingers`

##### <a name="-zabbix--startalerters"></a>`startalerters`

Data type: `Integer[1, 100]`

Number of pre-forked instances of alerters.

Default value: `$zabbix::params::server_startalerters`

##### <a name="-zabbix--startdiscoverers"></a>`startdiscoverers`

Data type: `Any`

Number of pre-forked instances of discoverers.

Default value: `$zabbix::params::server_startdiscoverers`

##### <a name="-zabbix--startescalators"></a>`startescalators`

Data type: `Integer[1, 100]`

Number of pre-forked instances of escalators.

Default value: `$zabbix::params::server_startescalators`

##### <a name="-zabbix--starthttppollers"></a>`starthttppollers`

Data type: `Any`

Number of pre-forked instances of http pollers.

Default value: `$zabbix::params::server_starthttppollers`

##### <a name="-zabbix--starttimers"></a>`starttimers`

Data type: `Any`

Number of pre-forked instances of timers.

Default value: `$zabbix::params::server_starttimers`

##### <a name="-zabbix--javagateway"></a>`javagateway`

Data type: `Any`

IP address (or hostname) of zabbix java gateway.

Default value: `$zabbix::params::server_javagateway`

##### <a name="-zabbix--javagatewayport"></a>`javagatewayport`

Data type: `Any`

Port that zabbix java gateway listens on.

Default value: `$zabbix::params::server_javagatewayport`

##### <a name="-zabbix--startjavapollers"></a>`startjavapollers`

Data type: `Any`

Number of pre-forked instances of java pollers.

Default value: `$zabbix::params::server_startjavapollers`

##### <a name="-zabbix--startlldprocessors"></a>`startlldprocessors`

Data type: `Integer[1, 100]`

Number of pre-forked instances of low-level discovery (LLD) workers.

Default value: `$zabbix::params::server_startlldprocessors`

##### <a name="-zabbix--startvmwarecollectors"></a>`startvmwarecollectors`

Data type: `Any`

Number of pre-forked vmware collector instances.

Default value: `$zabbix::params::server_startvmwarecollectors`

##### <a name="-zabbix--vaultdbpath"></a>`vaultdbpath`

Data type: `Optional[String[1]]`

Vault path from where credentials for database will be retrieved by keys 'password' and 'username'.

Default value: `$zabbix::params::server_vaultdbpath`

##### <a name="-zabbix--vaulttoken"></a>`vaulttoken`

Data type: `Optional[String[1]]`

Vault authentication token that should have been generated exclusively for Zabbix proxy with read-only
permission to the path specified in the optional VaultDBPath configuration parameter.

Default value: `$zabbix::params::server_vaulttoken`

##### <a name="-zabbix--vaulturl"></a>`vaulturl`

Data type: `Stdlib::HTTPSUrl`

Vault server HTTP[S] URL. System-wide CA certificates directory will be used if SSLCALocation is not specified.

Default value: `$zabbix::params::server_vaulturl`

##### <a name="-zabbix--vmwarefrequency"></a>`vmwarefrequency`

Data type: `Any`

How often zabbix will connect to vmware service to obtain a new datan.

Default value: `$zabbix::params::server_vmwarefrequency`

##### <a name="-zabbix--vmwarecachesize"></a>`vmwarecachesize`

Data type: `Any`

Size of vmware cache, in bytes.

Default value: `$zabbix::params::server_vmwarecachesize`

##### <a name="-zabbix--vmwaretimeout"></a>`vmwaretimeout`

Data type: `Any`

The maximum number of seconds vmware collector will wait for a response from VMware service.

Default value: `$zabbix::params::server_vmwaretimeout`

##### <a name="-zabbix--snmptrapperfile"></a>`snmptrapperfile`

Data type: `Any`

Temporary file used for passing data from snmp trap daemon to the server.

Default value: `$zabbix::params::server_snmptrapperfile`

##### <a name="-zabbix--startsnmptrapper"></a>`startsnmptrapper`

Data type: `Any`

If 1, snmp trapper process is started.

Default value: `$zabbix::params::server_startsnmptrapper`

##### <a name="-zabbix--listenip"></a>`listenip`

Data type: `Any`

List of comma delimited ip addresses that the zabbix-server should listen on.

Default value: `$zabbix::params::server_listenip`

##### <a name="-zabbix--housekeepingfrequency"></a>`housekeepingfrequency`

Data type: `Any`

How often zabbix will perform housekeeping procedure (in hours).

Default value: `$zabbix::params::server_housekeepingfrequency`

##### <a name="-zabbix--maxhousekeeperdelete"></a>`maxhousekeeperdelete`

Data type: `Any`

the table "housekeeper" contains "tasks" for housekeeping procedure in the format:
[housekeeperid], [tablename], [field], [value].
no more than 'maxhousekeeperdelete' rows (corresponding to [tablename], [field], [value])
will be deleted per one task in one housekeeping cycle.
sqlite3 does not use this parameter, deletes all corresponding rows without a limit.
if set to 0 then no limit is used at all. in this case you must know what you are doing!

Default value: `$zabbix::params::server_maxhousekeeperdelete`

##### <a name="-zabbix--cachesize"></a>`cachesize`

Data type: `Any`

Size of configuration cache, in bytes.

Default value: `$zabbix::params::server_cachesize`

##### <a name="-zabbix--cacheupdatefrequency"></a>`cacheupdatefrequency`

Data type: `Any`

How often zabbix will perform update of configuration cache, in seconds.

Default value: `$zabbix::params::server_cacheupdatefrequency`

##### <a name="-zabbix--startdbsyncers"></a>`startdbsyncers`

Data type: `Any`

Number of pre-forked instances of db syncers.

Default value: `$zabbix::params::server_startdbsyncers`

##### <a name="-zabbix--historycachesize"></a>`historycachesize`

Data type: `Any`

Size of history cache, in bytes.

Default value: `$zabbix::params::server_historycachesize`

##### <a name="-zabbix--historyindexcachesize"></a>`historyindexcachesize`

Data type: `Zabbix::Historyics`

Size of history index cache, in bytes.

Default value: `$zabbix::params::server_historyindexcachesize`

##### <a name="-zabbix--trendcachesize"></a>`trendcachesize`

Data type: `Any`

Size of trend cache, in bytes.

Default value: `$zabbix::params::server_trendcachesize`

##### <a name="-zabbix--valuecachesize"></a>`valuecachesize`

Data type: `Any`

Size of history value cache, in bytes.

Default value: `$zabbix::params::server_valuecachesize`

##### <a name="-zabbix--timeout"></a>`timeout`

Data type: `Any`

Specifies how long we wait for agent, snmp device or external check (in seconds).

Default value: `$zabbix::params::server_timeout`

##### <a name="-zabbix--tlscafile"></a>`tlscafile`

Data type: `Any`

Full pathname of a file containing the top-level CA(s) certificates for peer certificate verification.

Default value: `$zabbix::params::server_tlscafile`

##### <a name="-zabbix--tlscertfile"></a>`tlscertfile`

Data type: `Any`

Full pathname of a file containing the server certificate or certificate chain.

Default value: `$zabbix::params::server_tlscertfile`

##### <a name="-zabbix--tlscrlfile"></a>`tlscrlfile`

Data type: `Any`

Full pathname of a file containing revoked certificates.

Default value: `$zabbix::params::server_tlscrlfile`

##### <a name="-zabbix--tlskeyfile"></a>`tlskeyfile`

Data type: `Any`

Full pathname of a file containing the server private key.

Default value: `$zabbix::params::server_tlskeyfile`

##### <a name="-zabbix--tlscipherall"></a>`tlscipherall`

Data type: `Any`

GnuTLS priority string or OpenSSL (TLS 1.2) cipher string. Override the default ciphersuite selection criteria
for certificate- and PSK-based encryption.

Default value: `$zabbix::params::server_tlscipherall`

##### <a name="-zabbix--tlscipherall13"></a>`tlscipherall13`

Data type: `Any`

Cipher string for OpenSSL 1.1.1 or newer in TLS 1.3. Override the default ciphersuite selection criteria
for certificate- and PSK-based encryption.

Default value: `$zabbix::params::server_tlscipherall13`

##### <a name="-zabbix--tlsciphercert"></a>`tlsciphercert`

Data type: `Any`

GnuTLS priority string or OpenSSL (TLS 1.2) cipher string. Override the default ciphersuite selection criteria
for certificate-based encryption.

Default value: `$zabbix::params::server_tlsciphercert`

##### <a name="-zabbix--tlsciphercert13"></a>`tlsciphercert13`

Data type: `Any`

Cipher string for OpenSSL 1.1.1 or newer in TLS 1.3. Override the default ciphersuite selection criteria
for certificate-based encryption.

Default value: `$zabbix::params::server_tlsciphercert13`

##### <a name="-zabbix--tlscipherpsk"></a>`tlscipherpsk`

Data type: `Any`

GnuTLS priority string or OpenSSL (TLS 1.2) cipher string. Override the default ciphersuite selection criteria
for PSK-based encryption.

Default value: `$zabbix::params::server_tlscipherpsk`

##### <a name="-zabbix--tlscipherpsk13"></a>`tlscipherpsk13`

Data type: `Any`

Cipher string for OpenSSL 1.1.1 or newer in TLS 1.3. Override the default ciphersuite selection criteria
for PSK-based encryption.

Default value: `$zabbix::params::server_tlscipherpsk13`

##### <a name="-zabbix--trappertimeout"></a>`trappertimeout`

Data type: `Any`

Specifies how many seconds trapper may spend processing new data.

Default value: `$zabbix::params::server_trappertimeout`

##### <a name="-zabbix--unreachableperiod"></a>`unreachableperiod`

Data type: `Any`

After how many seconds of unreachability treat a host as unavailable.

Default value: `$zabbix::params::server_unreachableperiod`

##### <a name="-zabbix--unavailabledelay"></a>`unavailabledelay`

Data type: `Any`

How often host is checked for availability during the unavailability period, in seconds.

Default value: `$zabbix::params::server_unavailabledelay`

##### <a name="-zabbix--unreachabledelay"></a>`unreachabledelay`

Data type: `Any`

How often host is checked for availability during the unreachability period, in seconds.

Default value: `$zabbix::params::server_unreachabledelay`

##### <a name="-zabbix--alertscriptspath"></a>`alertscriptspath`

Data type: `Any`

Full path to location of custom alert scripts.

Default value: `$zabbix::params::server_alertscriptspath`

##### <a name="-zabbix--externalscripts"></a>`externalscripts`

Data type: `Any`

Full path to location of external scripts.

Default value: `$zabbix::params::server_externalscripts`

##### <a name="-zabbix--fpinglocation"></a>`fpinglocation`

Data type: `Any`

Location of fping.

Default value: `$zabbix::params::server_fpinglocation`

##### <a name="-zabbix--fping6location"></a>`fping6location`

Data type: `Any`

Location of fping6.

Default value: `$zabbix::params::server_fping6location`

##### <a name="-zabbix--sshkeylocation"></a>`sshkeylocation`

Data type: `Any`

Location of public and private keys for ssh checks and actions.

Default value: `$zabbix::params::server_sshkeylocation`

##### <a name="-zabbix--logslowqueries"></a>`logslowqueries`

Data type: `Any`

How long a database query may take before being logged (in milliseconds).

Default value: `$zabbix::params::server_logslowqueries`

##### <a name="-zabbix--tmpdir"></a>`tmpdir`

Data type: `Any`

Temporary directory.

Default value: `$zabbix::params::server_tmpdir`

##### <a name="-zabbix--startproxypollers"></a>`startproxypollers`

Data type: `Any`

Number of pre-forked instances of pollers for passive proxies.

Default value: `$zabbix::params::server_startproxypollers`

##### <a name="-zabbix--proxyconfigfrequency"></a>`proxyconfigfrequency`

Data type: `Any`

How often zabbix server sends configuration data to a zabbix proxy in seconds.

Default value: `$zabbix::params::server_proxyconfigfrequency`

##### <a name="-zabbix--proxydatafrequency"></a>`proxydatafrequency`

Data type: `Any`

How often zabbix server requests history data from a zabbix proxy in seconds.

Default value: `$zabbix::params::server_proxydatafrequency`

##### <a name="-zabbix--allowroot"></a>`allowroot`

Data type: `Any`

Allow the server to run as 'root'.

Default value: `$zabbix::params::server_allowroot`

##### <a name="-zabbix--include_dir"></a>`include_dir`

Data type: `Any`

You may include individual files or all files in a directory in the configuration file.

Default value: `$zabbix::params::server_include`

##### <a name="-zabbix--loadmodulepath"></a>`loadmodulepath`

Data type: `Any`

Full path to location of server modules.

Default value: `$zabbix::params::server_loadmodulepath`

##### <a name="-zabbix--loadmodule"></a>`loadmodule`

Data type: `Any`

Module to load at server startup.

Default value: `$zabbix::params::server_loadmodule`

##### <a name="-zabbix--socketdir"></a>`socketdir`

Data type: `Optional[Stdlib::Absolutepath]`

IPC socket directory.
Directory to store IPC sockets used by internal Zabbix services.

Default value: `$zabbix::params::server_socketdir`

##### <a name="-zabbix--manage_selinux"></a>`manage_selinux`

Data type: `Boolean`

Whether we should manage SELinux rules.

Default value: `$zabbix::params::manage_selinux`

##### <a name="-zabbix--additional_service_params"></a>`additional_service_params`

Data type: `String`

Additional parameters to pass to the service.

Default value: `$zabbix::params::additional_service_params`

##### <a name="-zabbix--zabbix_user"></a>`zabbix_user`

Data type: `Optional[String[1]]`

User the zabbix service will run as.

Default value: `$zabbix::params::server_zabbix_user`

##### <a name="-zabbix--zabbix_server_name"></a>`zabbix_server_name`

Data type: `Optional[String]`

The fqdn name of the host running the zabbix-server. When single node:
localhost
This can also be used to upave a different name such as "Zabbix DEV"

Default value: `$zabbix::params::zabbix_server`

##### <a name="-zabbix--saml_sp_key"></a>`saml_sp_key`

Data type: `Optional[Stdlib::Absolutepath]`

The location of the SAML Service Provider Key file.

Default value: `$zabbix::params::saml_sp_key`

##### <a name="-zabbix--saml_sp_cert"></a>`saml_sp_cert`

Data type: `Optional[Stdlib::Absolutepath]`

The location of the SAML Service Provider Certificate.

Default value: `$zabbix::params::saml_sp_cert`

##### <a name="-zabbix--saml_idp_cert"></a>`saml_idp_cert`

Data type: `Optional[Stdlib::Absolutepath]`

The location of the SAML Identity Provider Certificate.

Default value: `$zabbix::params::saml_idp_cert`

##### <a name="-zabbix--saml_settings"></a>`saml_settings`

Data type: `Hash[String[1], Variant[ScalarData, Hash]]`

A hash of additional SAML SSO settings.

Default value: `$zabbix::params::saml_settings`

### <a name="zabbix--agent"></a>`zabbix::agent`

This will install and configure the zabbix-agent deamon

#### Examples

##### Basic installation:

```puppet
class { 'zabbix::agent':
  zabbix_version => '6.0',
  server         => '192.168.1.1',
}
```

##### With exported resources:

```puppet
class { 'zabbix::agent':
  manage_resources   => true,
  monitored_by_proxy => 'my_proxy_host',
  server             => '192.168.1.1',
}
```

##### Using Zabbix Agent 2

```puppet
class { 'zabbix::agent':
  agent_configfile_path => '/etc/zabbix/zabbix_agent2.conf',
  include_dir           => '/etc/zabbix/zabbix_agent2.d',
  include_dir_purge     => false,
  zabbix_package_agent  => 'zabbix-agent2',
  servicename           => 'zabbix-agent2',
  manage_startup_script => false,
}
```

#### Parameters

The following parameters are available in the `zabbix::agent` class:

* [`zabbix_version`](#-zabbix--agent--zabbix_version)
* [`zabbix_package_state`](#-zabbix--agent--zabbix_package_state)
* [`zabbix_package_agent`](#-zabbix--agent--zabbix_package_agent)
* [`manage_firewall`](#-zabbix--agent--manage_firewall)
* [`manage_repo`](#-zabbix--agent--manage_repo)
* [`manage_choco`](#-zabbix--agent--manage_choco)
* [`zabbix_package_provider`](#-zabbix--agent--zabbix_package_provider)
* [`zabbix_package_source`](#-zabbix--agent--zabbix_package_source)
* [`manage_resources`](#-zabbix--agent--manage_resources)
* [`monitored_by_proxy`](#-zabbix--agent--monitored_by_proxy)
* [`agent_use_ip`](#-zabbix--agent--agent_use_ip)
* [`zbx_groups`](#-zabbix--agent--zbx_groups)
* [`zbx_group_create`](#-zabbix--agent--zbx_group_create)
* [`zbx_templates`](#-zabbix--agent--zbx_templates)
* [`zbx_macros`](#-zabbix--agent--zbx_macros)
* [`zbx_interface_type`](#-zabbix--agent--zbx_interface_type)
* [`zbx_interface_details`](#-zabbix--agent--zbx_interface_details)
* [`agent_configfile_path`](#-zabbix--agent--agent_configfile_path)
* [`pidfile`](#-zabbix--agent--pidfile)
* [`servicename`](#-zabbix--agent--servicename)
* [`logfile`](#-zabbix--agent--logfile)
* [`logfilesize`](#-zabbix--agent--logfilesize)
* [`logtype`](#-zabbix--agent--logtype)
* [`debuglevel`](#-zabbix--agent--debuglevel)
* [`sourceip`](#-zabbix--agent--sourceip)
* [`allowkey`](#-zabbix--agent--allowkey)
* [`denykey`](#-zabbix--agent--denykey)
* [`enableremotecommands`](#-zabbix--agent--enableremotecommands)
* [`logremotecommands`](#-zabbix--agent--logremotecommands)
* [`server`](#-zabbix--agent--server)
* [`listenport`](#-zabbix--agent--listenport)
* [`listenip`](#-zabbix--agent--listenip)
* [`startagents`](#-zabbix--agent--startagents)
* [`serveractive`](#-zabbix--agent--serveractive)
* [`service_ensure`](#-zabbix--agent--service_ensure)
* [`service_enable`](#-zabbix--agent--service_enable)
* [`hostname`](#-zabbix--agent--hostname)
* [`hostnameitem`](#-zabbix--agent--hostnameitem)
* [`hostmetadata`](#-zabbix--agent--hostmetadata)
* [`hostmetadataitem`](#-zabbix--agent--hostmetadataitem)
* [`hostinterface`](#-zabbix--agent--hostinterface)
* [`hostinterfaceitem`](#-zabbix--agent--hostinterfaceitem)
* [`refreshactivechecks`](#-zabbix--agent--refreshactivechecks)
* [`buffersend`](#-zabbix--agent--buffersend)
* [`buffersize`](#-zabbix--agent--buffersize)
* [`maxlinespersecond`](#-zabbix--agent--maxlinespersecond)
* [`allowroot`](#-zabbix--agent--allowroot)
* [`zabbix_user`](#-zabbix--agent--zabbix_user)
* [`zabbix_alias`](#-zabbix--agent--zabbix_alias)
* [`timeout`](#-zabbix--agent--timeout)
* [`tlsaccept`](#-zabbix--agent--tlsaccept)
* [`tlscafile`](#-zabbix--agent--tlscafile)
* [`tlscertfile`](#-zabbix--agent--tlscertfile)
* [`tlscertissuer`](#-zabbix--agent--tlscertissuer)
* [`tlscertsubject`](#-zabbix--agent--tlscertsubject)
* [`tlsconnect`](#-zabbix--agent--tlsconnect)
* [`tlscrlfile`](#-zabbix--agent--tlscrlfile)
* [`tlskeyfile`](#-zabbix--agent--tlskeyfile)
* [`tlspskfile`](#-zabbix--agent--tlspskfile)
* [`tlspskidentity`](#-zabbix--agent--tlspskidentity)
* [`tlscipherall`](#-zabbix--agent--tlscipherall)
* [`tlscipherall13`](#-zabbix--agent--tlscipherall13)
* [`tlsciphercert`](#-zabbix--agent--tlsciphercert)
* [`tlsciphercert13`](#-zabbix--agent--tlsciphercert13)
* [`tlscipherpsk`](#-zabbix--agent--tlscipherpsk)
* [`tlscipherpsk13`](#-zabbix--agent--tlscipherpsk13)
* [`tlsservercertissuer`](#-zabbix--agent--tlsservercertissuer)
* [`tlsservercertsubject`](#-zabbix--agent--tlsservercertsubject)
* [`agent_config_owner`](#-zabbix--agent--agent_config_owner)
* [`agent_config_group`](#-zabbix--agent--agent_config_group)
* [`manage_selinux`](#-zabbix--agent--manage_selinux)
* [`selinux_require`](#-zabbix--agent--selinux_require)
* [`selinux_rules`](#-zabbix--agent--selinux_rules)
* [`additional_service_params`](#-zabbix--agent--additional_service_params)
* [`service_type`](#-zabbix--agent--service_type)
* [`include_dir`](#-zabbix--agent--include_dir)
* [`include_dir_purge`](#-zabbix--agent--include_dir_purge)
* [`unsafeuserparameters`](#-zabbix--agent--unsafeuserparameters)
* [`userparameter`](#-zabbix--agent--userparameter)
* [`loadmodulepath`](#-zabbix--agent--loadmodulepath)
* [`loadmodule`](#-zabbix--agent--loadmodule)
* [`manage_startup_script`](#-zabbix--agent--manage_startup_script)

##### <a name="-zabbix--agent--zabbix_version"></a>`zabbix_version`

Data type: `Any`

This is the zabbix version.

Default value: `$zabbix::params::zabbix_version`

##### <a name="-zabbix--agent--zabbix_package_state"></a>`zabbix_package_state`

Data type: `Any`

The state of the package that needs to be installed: present or latest.

Default value: `$zabbix::params::zabbix_package_state`

##### <a name="-zabbix--agent--zabbix_package_agent"></a>`zabbix_package_agent`

Data type: `Any`

The name of the agent package that we manage

Default value: `$zabbix::params::zabbix_package_agent`

##### <a name="-zabbix--agent--manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

When true, it will create iptables rules.

Default value: `$zabbix::params::manage_firewall`

##### <a name="-zabbix--agent--manage_repo"></a>`manage_repo`

Data type: `Boolean`

When true, it will create repository for installing the agent.

Default value: `$zabbix::params::manage_repo`

##### <a name="-zabbix--agent--manage_choco"></a>`manage_choco`

Data type: `Boolean`

When true on windows, it will use chocolatey to install the agent.
The module chocolatey is required https://forge.puppet.com/puppetlabs/chocolatey.

Default value: `$zabbix::params::manage_choco`

##### <a name="-zabbix--agent--zabbix_package_provider"></a>`zabbix_package_provider`

Data type: `Optional[String[1]]`

Which package's provider to use to install the agent.
It is undef for all linux os and set to 'chocolatey' on windows.

Default value: `$zabbix::params::zabbix_package_provider`

##### <a name="-zabbix--agent--zabbix_package_source"></a>`zabbix_package_source`

Data type: `Optional[Stdlib::Windowspath]`

Path to a Windows MSI file used to install the agent.

Default value: `undef`

##### <a name="-zabbix--agent--manage_resources"></a>`manage_resources`

Data type: `Boolean`

When true, it will export resources to something like puppetdb.
When set to true, you'll need to configure 'storeconfigs' to make
this happen. Default is set to false, as not everyone has this
enabled.

Default value: `$zabbix::params::manage_resources`

##### <a name="-zabbix--agent--monitored_by_proxy"></a>`monitored_by_proxy`

Data type: `Any`

When this is monitored by an proxy, please fill in the name of this proxy.
If the proxy is also installed via this module, please fill in the FQDN

Default value: `$zabbix::params::monitored_by_proxy`

##### <a name="-zabbix--agent--agent_use_ip"></a>`agent_use_ip`

Data type: `Any`

When true, when creating hosts via the zabbix-api, it will configure that
connection should me made via ip, not fqdn.

Default value: `$zabbix::params::agent_use_ip`

##### <a name="-zabbix--agent--zbx_groups"></a>`zbx_groups`

Data type: `Variant[String[1],Array[String[1]]]`

An array of hostgroups where this host needs to be added.

Default value: `$zabbix::params::agent_zbx_groups`

##### <a name="-zabbix--agent--zbx_group_create"></a>`zbx_group_create`

Data type: `Any`

Whether to create hostgroup if missing.

Default value: `$zabbix::params::agent_zbx_group_create`

##### <a name="-zabbix--agent--zbx_templates"></a>`zbx_templates`

Data type: `Any`

List of templates which will be added when host is configured.

Default value: `$zabbix::params::agent_zbx_templates`

##### <a name="-zabbix--agent--zbx_macros"></a>`zbx_macros`

Data type: `Array[Hash]`

List of macros which will be added when host is configured.

Default value: `[]`

##### <a name="-zabbix--agent--zbx_interface_type"></a>`zbx_interface_type`

Data type: `Integer[1,4]`

Integer specifying type of interface to be created.

Default value: `1`

##### <a name="-zabbix--agent--zbx_interface_details"></a>`zbx_interface_details`

Data type: `Variant[Array, Hash]`

Hash with interface details for SNMP when interface type is 2.

Default value: `[]`

##### <a name="-zabbix--agent--agent_configfile_path"></a>`agent_configfile_path`

Data type: `Any`

Agent config file path defaults to /etc/zabbix/zabbix_agentd.conf.

Default value: `$zabbix::params::agent_configfile_path`

##### <a name="-zabbix--agent--pidfile"></a>`pidfile`

Data type: `Any`

Name of pid file.

Default value: `$zabbix::params::agent_pidfile`

##### <a name="-zabbix--agent--servicename"></a>`servicename`

Data type: `Any`

Zabbix's agent service name.

Default value: `$zabbix::params::agent_servicename`

##### <a name="-zabbix--agent--logfile"></a>`logfile`

Data type: `Optional[Stdlib::Absolutepath]`

Name of log file.

Default value: `$zabbix::params::agent_logfile`

##### <a name="-zabbix--agent--logfilesize"></a>`logfilesize`

Data type: `Any`

Maximum size of log file in MB.

Default value: `$zabbix::params::agent_logfilesize`

##### <a name="-zabbix--agent--logtype"></a>`logtype`

Data type: `Enum['console', 'file', 'system']`

Specifies where log messages are written to. Can be one of: console, file, system.

Default value: `$zabbix::params::agent_logtype`

##### <a name="-zabbix--agent--debuglevel"></a>`debuglevel`

Data type: `Any`

Specifies debug level.

Default value: `$zabbix::params::agent_debuglevel`

##### <a name="-zabbix--agent--sourceip"></a>`sourceip`

Data type: `Any`

Source ip address for outgoing connections.

Default value: `$zabbix::params::agent_sourceip`

##### <a name="-zabbix--agent--allowkey"></a>`allowkey`

Data type: `Optional[String[1]]`

Allow execution of item keys matching pattern.

Default value: `$zabbix::params::agent_allowkey`

##### <a name="-zabbix--agent--denykey"></a>`denykey`

Data type: `Optional[String[1]]`

Deny execution of items keys matching pattern.

Default value: `$zabbix::params::agent_denykey`

##### <a name="-zabbix--agent--enableremotecommands"></a>`enableremotecommands`

Data type: `Any`

Whether remote commands from zabbix server are allowed.

Default value: `$zabbix::params::agent_enableremotecommands`

##### <a name="-zabbix--agent--logremotecommands"></a>`logremotecommands`

Data type: `Any`

Enable logging of executed shell commands as warnings.

Default value: `$zabbix::params::agent_logremotecommands`

##### <a name="-zabbix--agent--server"></a>`server`

Data type: `Any`

List of comma delimited ip addresses (or hostnames) of zabbix servers.

Default value: `$zabbix::params::agent_server`

##### <a name="-zabbix--agent--listenport"></a>`listenport`

Data type: `Any`

Agent will listen on this port for connections from the server.

Default value: `$zabbix::params::agent_listenport`

##### <a name="-zabbix--agent--listenip"></a>`listenip`

Data type: `Any`

List of comma delimited ip addresses that the agent should listen on.
You can also specify which network interface it should listen on.

listenip => 'eth0',  or
listenip => 'bond0.73',

It will find out which ip is configured for this ipaddress. Can be handy
if more than 1 interface is on the server.

Default value: `$zabbix::params::agent_listenip`

##### <a name="-zabbix--agent--startagents"></a>`startagents`

Data type: `Any`

Number of pre-forked instances of zabbix_agentd that process passive checks.

Default value: `$zabbix::params::agent_startagents`

##### <a name="-zabbix--agent--serveractive"></a>`serveractive`

Data type: `Any`

List of comma delimited ip:port (or hostname:port) pairs of zabbix servers for active checks.

Default value: `$zabbix::params::agent_serveractive`

##### <a name="-zabbix--agent--service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`

Start / stop the agent service. E.g. to preconfigure a hosts agent and turn on the service at a later time (when the server reaches production SLA)

Default value: `$zabbix::params::agent_service_ensure`

##### <a name="-zabbix--agent--service_enable"></a>`service_enable`

Data type: `Boolean`

Automatically start the agent on system boot

Default value: `$zabbix::params::agent_service_enable`

##### <a name="-zabbix--agent--hostname"></a>`hostname`

Data type: `Any`

Unique, case sensitive hostname.

Default value: `$zabbix::params::agent_hostname`

##### <a name="-zabbix--agent--hostnameitem"></a>`hostnameitem`

Data type: `Any`

Zabbix item used for generating hostname if it is undefined.

Default value: `$zabbix::params::agent_hostnameitem`

##### <a name="-zabbix--agent--hostmetadata"></a>`hostmetadata`

Data type: `Any`

Optional parameter that defines host metadata.

Default value: `$zabbix::params::agent_hostmetadata`

##### <a name="-zabbix--agent--hostmetadataitem"></a>`hostmetadataitem`

Data type: `Any`

Optional parameter that defines a zabbix item used for getting host metadata.

Default value: `$zabbix::params::agent_hostmetadataitem`

##### <a name="-zabbix--agent--hostinterface"></a>`hostinterface`

Data type: `Optional[Stdlib::Fqdn]`

Optional parameter that defines host metadata. Host metadata is used only at host
auto-registration process (active agent).

Default value: `$zabbix::params::agent_hostinterface`

##### <a name="-zabbix--agent--hostinterfaceitem"></a>`hostinterfaceitem`

Data type: `Optional[Stdlib::Fqdn]`

Optional parameter that defines an item used for getting host interface.
Host interface is used at host auto-registration process.

Default value: `$zabbix::params::agent_hostinterfaceitem`

##### <a name="-zabbix--agent--refreshactivechecks"></a>`refreshactivechecks`

Data type: `Any`

How often list of active checks is refreshed, in seconds.

Default value: `$zabbix::params::agent_refreshactivechecks`

##### <a name="-zabbix--agent--buffersend"></a>`buffersend`

Data type: `Any`

Do not keep data longer than n seconds in buffer.

Default value: `$zabbix::params::agent_buffersend`

##### <a name="-zabbix--agent--buffersize"></a>`buffersize`

Data type: `Any`

Maximum number of values in a memory buffer.

Default value: `$zabbix::params::agent_buffersize`

##### <a name="-zabbix--agent--maxlinespersecond"></a>`maxlinespersecond`

Data type: `Any`

Maximum number of new lines the agent will send per second to zabbix server or proxy processing.

Default value: `$zabbix::params::agent_maxlinespersecond`

##### <a name="-zabbix--agent--allowroot"></a>`allowroot`

Data type: `Any`

Allow the agent to run as 'root'.

Default value: `$zabbix::params::agent_allowroot`

##### <a name="-zabbix--agent--zabbix_user"></a>`zabbix_user`

Data type: `Optional[String[1]]`

Drop privileges to a specific, existing user on the system. Only has effect if run as 'root' and AllowRoot is disabled.

Default value: `$zabbix::params::agent_zabbix_user`

##### <a name="-zabbix--agent--zabbix_alias"></a>`zabbix_alias`

Data type: `Optional[Array]`

Sets an alias for parameter.

Default value: `$zabbix::params::agent_zabbix_alias`

##### <a name="-zabbix--agent--timeout"></a>`timeout`

Data type: `Any`

Spend no more than timeout seconds on processing.

Default value: `$zabbix::params::agent_timeout`

##### <a name="-zabbix--agent--tlsaccept"></a>`tlsaccept`

Data type: `Optional[Enum['unencrypted','psk','cert']]`

What incoming connections to accept from Zabbix server. Used for a passive proxy, ignored on an active proxy.

Default value: `$zabbix::params::agent_tlsaccept`

##### <a name="-zabbix--agent--tlscafile"></a>`tlscafile`

Data type: `Any`

Full pathname of a file containing the top-level CA(s) certificates for peer certificate verification.

Default value: `$zabbix::params::agent_tlscafile`

##### <a name="-zabbix--agent--tlscertfile"></a>`tlscertfile`

Data type: `Any`

Full pathname of a file containing the proxy certificate or certificate chain.

Default value: `$zabbix::params::agent_tlscertfile`

##### <a name="-zabbix--agent--tlscertissuer"></a>`tlscertissuer`

Data type: `Optional[String[1]]`

Issuer of the certificate that is allowed to talk with the serve

Default value: `undef`

##### <a name="-zabbix--agent--tlscertsubject"></a>`tlscertsubject`

Data type: `Optional[String[1]]`

Subject of the certificate that is allowed to talk with the server

Default value: `undef`

##### <a name="-zabbix--agent--tlsconnect"></a>`tlsconnect`

Data type: `Optional[Enum['unencrypted','psk','cert']]`

How the proxy should connect to Zabbix server. Used for an active proxy, ignored on a passive proxy.

Default value: `$zabbix::params::agent_tlsconnect`

##### <a name="-zabbix--agent--tlscrlfile"></a>`tlscrlfile`

Data type: `Any`

Full pathname of a file containing revoked certificates.

Default value: `$zabbix::params::agent_tlscrlfile`

##### <a name="-zabbix--agent--tlskeyfile"></a>`tlskeyfile`

Data type: `Any`

Full pathname of a file containing the proxy private key.

Default value: `$zabbix::params::agent_tlskeyfile`

##### <a name="-zabbix--agent--tlspskfile"></a>`tlspskfile`

Data type: `Any`

Full pathname of a file containing the pre-shared key.

Default value: `$zabbix::params::agent_tlspskfile`

##### <a name="-zabbix--agent--tlspskidentity"></a>`tlspskidentity`

Data type: `Any`

Unique, case sensitive string used to identify the pre-shared key.

Default value: `$zabbix::params::agent_tlspskidentity`

##### <a name="-zabbix--agent--tlscipherall"></a>`tlscipherall`

Data type: `Optional[String[1]]`

GnuTLS priority string or OpenSSL (TLS 1.2) cipher string. Override the default ciphersuite selection criteria
for certificate- and PSK-based encryption.

Default value: `$zabbix::params::agent_tlscipherall`

##### <a name="-zabbix--agent--tlscipherall13"></a>`tlscipherall13`

Data type: `Optional[String[1]]`

Cipher string for OpenSSL 1.1.1 or newer in TLS 1.3. Override the default ciphersuite selection criteria
for certificate- and PSK-based encryption.

Default value: `$zabbix::params::agent_tlscipherall13`

##### <a name="-zabbix--agent--tlsciphercert"></a>`tlsciphercert`

Data type: `Optional[String[1]]`

GnuTLS priority string or OpenSSL (TLS 1.2) cipher string. Override the default ciphersuite selection criteria
for certificate-based encryption.

Default value: `$zabbix::params::agent_tlsciphercert`

##### <a name="-zabbix--agent--tlsciphercert13"></a>`tlsciphercert13`

Data type: `Optional[String[1]]`

Cipher string for OpenSSL 1.1.1 or newer in TLS 1.3. Override the default ciphersuite selection criteria
for certificate-based encryption.

Default value: `$zabbix::params::agent_tlsciphercert13`

##### <a name="-zabbix--agent--tlscipherpsk"></a>`tlscipherpsk`

Data type: `Optional[String[1]]`

GnuTLS priority string or OpenSSL (TLS 1.2) cipher string. Override the default ciphersuite selection criteria
for PSK-based encryption.

Default value: `$zabbix::params::agent_tlscipherpsk`

##### <a name="-zabbix--agent--tlscipherpsk13"></a>`tlscipherpsk13`

Data type: `Optional[String[1]]`

Cipher string for OpenSSL 1.1.1 or newer in TLS 1.3. Override the default ciphersuite selection criteria
for PSK-based encryption.

Default value: `$zabbix::params::agent_tlscipherpsk13`

##### <a name="-zabbix--agent--tlsservercertissuer"></a>`tlsservercertissuer`

Data type: `Any`

Allowed server certificate issuer.

Default value: `$zabbix::params::agent_tlsservercertissuer`

##### <a name="-zabbix--agent--tlsservercertsubject"></a>`tlsservercertsubject`

Data type: `Any`

Allowed server certificate subject.

Default value: `$zabbix::params::agent_tlsservercertsubject`

##### <a name="-zabbix--agent--agent_config_owner"></a>`agent_config_owner`

Data type: `Optional[String[1]]`

The owner of Zabbix's agent config file.

Default value: `$zabbix::params::agent_config_owner`

##### <a name="-zabbix--agent--agent_config_group"></a>`agent_config_group`

Data type: `Optional[String[1]]`

The group of Zabbix's agent config file.

Default value: `$zabbix::params::agent_config_group`

##### <a name="-zabbix--agent--manage_selinux"></a>`manage_selinux`

Data type: `Boolean`

Whether the module should manage SELinux rules or not.

Default value: `$zabbix::params::manage_selinux`

##### <a name="-zabbix--agent--selinux_require"></a>`selinux_require`

Data type: `Array[String]`

An array of SELinux require {} rules.

Default value: `$zabbix::params::selinux_require`

##### <a name="-zabbix--agent--selinux_rules"></a>`selinux_rules`

Data type: `Hash[String, Array]`

A Hash of SELinux rules.

Default value: `$zabbix::params::selinux_rules`

##### <a name="-zabbix--agent--additional_service_params"></a>`additional_service_params`

Data type: `String`

Additional parameters to pass to the service.

Default value: `$zabbix::params::additional_service_params`

##### <a name="-zabbix--agent--service_type"></a>`service_type`

Data type: `String`

Systemd service type

Default value: `$zabbix::params::service_type`

##### <a name="-zabbix--agent--include_dir"></a>`include_dir`

Data type: `Any`

You may include individual files or all files in a directory in the configuration file.

Default value: `$zabbix::params::agent_include`

##### <a name="-zabbix--agent--include_dir_purge"></a>`include_dir_purge`

Data type: `Any`

Include dir to purge.

Default value: `$zabbix::params::agent_include_purge`

##### <a name="-zabbix--agent--unsafeuserparameters"></a>`unsafeuserparameters`

Data type: `Any`

Allow all characters to be passed in arguments to user-defined parameters.

Default value: `$zabbix::params::agent_unsafeuserparameters`

##### <a name="-zabbix--agent--userparameter"></a>`userparameter`

Data type: `Any`

User-defined parameter to monitor.

Default value: `$zabbix::params::agent_userparameter`

##### <a name="-zabbix--agent--loadmodulepath"></a>`loadmodulepath`

Data type: `Optional[String[1]]`

Full path to location of agent modules.

Default value: `$zabbix::params::agent_loadmodulepath`

##### <a name="-zabbix--agent--loadmodule"></a>`loadmodule`

Data type: `Any`

Module to load at agent startup.

Default value: `$zabbix::params::agent_loadmodule`

##### <a name="-zabbix--agent--manage_startup_script"></a>`manage_startup_script`

Data type: `Boolean`

If the init script should be managed by this module. Attention: This might
cause problems with some config options of this module (e.g
agent_configfile_path)

Default value: `$zabbix::params::manage_startup_script`

### <a name="zabbix--database"></a>`zabbix::database`

This will install the correct database and one or more users for correct usage

#### Examples

##### The following is an example of an multiple host setup:

```puppet
node 'wdpuppet04.dj-wasabi.local' {
  #  class { 'postgresql::server':
  #    listen_addresses => '192.168.20.14'
  #  }
  class { 'mysql::server':
    override_options => {
      'mysqld'       => {
        'bind_address' => '192.168.20.14',
      },
    },
  }
  class { 'zabbix::database':
    database_type     => 'mysql',
    #zabbix_front_ip  => '192.168.20.12',
    #zabbix_server_ip => '192.168.20.13',
    zabbix_server     => 'wdpuppet03.dj-wasabi.local',
    zabbix_web        => 'wdpuppet02.dj-wasabi.local',
  }
}

The above example is when database_type = mysql. When you want to
use the postgresql as database, uncomment the lines of postgresql
class and both *_ip parameters. Comment the mysql class and comment
the zabbix_server and zabbix_web parameter.
```

#### Parameters

The following parameters are available in the `zabbix::database` class:

* [`zabbix_type`](#-zabbix--database--zabbix_type)
* [`zabbix_web`](#-zabbix--database--zabbix_web)
* [`zabbix_web_ip`](#-zabbix--database--zabbix_web_ip)
* [`zabbix_server`](#-zabbix--database--zabbix_server)
* [`zabbix_server_ip`](#-zabbix--database--zabbix_server_ip)
* [`zabbix_proxy`](#-zabbix--database--zabbix_proxy)
* [`zabbix_proxy_ip`](#-zabbix--database--zabbix_proxy_ip)
* [`manage_database`](#-zabbix--database--manage_database)
* [`database_type`](#-zabbix--database--database_type)
* [`database_schema_path`](#-zabbix--database--database_schema_path)
* [`database_name`](#-zabbix--database--database_name)
* [`database_user`](#-zabbix--database--database_user)
* [`database_password`](#-zabbix--database--database_password)
* [`database_host`](#-zabbix--database--database_host)
* [`database_host_ip`](#-zabbix--database--database_host_ip)
* [`database_charset`](#-zabbix--database--database_charset)
* [`database_collate`](#-zabbix--database--database_collate)
* [`database_tablespace`](#-zabbix--database--database_tablespace)

##### <a name="-zabbix--database--zabbix_type"></a>`zabbix_type`

Data type: `Any`

The type of zabbix which is used: server or proxy.
This will determine what sql files will be loaded into database.

Default value: `'server'`

##### <a name="-zabbix--database--zabbix_web"></a>`zabbix_web`

Data type: `Any`

This is the hostname of the server which is running the
zabbix-web package. This parameter is used when database_type =
mysql. When single node: localhost

Default value: `$zabbix::params::zabbix_web`

##### <a name="-zabbix--database--zabbix_web_ip"></a>`zabbix_web_ip`

Data type: `Any`

This is the ip address of the server which is running the
zabbix-web package. This parameter is used when database_type =
postgresql. When single node: 127.0.0.1

Default value: `$zabbix::params::zabbix_web_ip`

##### <a name="-zabbix--database--zabbix_server"></a>`zabbix_server`

Data type: `Any`

This is the FQDN for the host running zabbix-server. This parameter
is used when database_type = mysql. Default: localhost

Default value: `$zabbix::params::zabbix_server`

##### <a name="-zabbix--database--zabbix_server_ip"></a>`zabbix_server_ip`

Data type: `Any`

This is the actual ip address of the host running zabbix-server
This parameter is used when database_type = postgresql. Default:
127.0.0.1

Default value: `$zabbix::params::zabbix_server_ip`

##### <a name="-zabbix--database--zabbix_proxy"></a>`zabbix_proxy`

Data type: `Any`

This is the FQDN for the host running zabbix-proxy. This parameter
is used when database_type = mysql. Default: localhost

Default value: `$zabbix::params::zabbix_proxy`

##### <a name="-zabbix--database--zabbix_proxy_ip"></a>`zabbix_proxy_ip`

Data type: `Any`

This is the actual ip address of the host running zabbix-proxy
This parameter is used when database_type = postgresql. Default:
127.0.0.1

Default value: `$zabbix::params::zabbix_proxy_ip`

##### <a name="-zabbix--database--manage_database"></a>`manage_database`

Data type: `Any`

When set to true, it will create the database and will load
the sql files for basic setup. Otherwise you should do this manually.

Default value: `$zabbix::params::manage_database`

##### <a name="-zabbix--database--database_type"></a>`database_type`

Data type: `Zabbix::Databases`

The database which is used: postgresql or mysql

Default value: `$zabbix::params::database_type`

##### <a name="-zabbix--database--database_schema_path"></a>`database_schema_path`

Data type: `Any`

The path to the directory containing the .sql schema files

Default value: `$zabbix::params::database_schema_path`

##### <a name="-zabbix--database--database_name"></a>`database_name`

Data type: `Any`

The name of the database. Default: zabbix-server

Default value: `$zabbix::params::server_database_name`

##### <a name="-zabbix--database--database_user"></a>`database_user`

Data type: `Any`

The user which is used for connecting to the database

Default value: `$zabbix::params::server_database_user`

##### <a name="-zabbix--database--database_password"></a>`database_password`

Data type: `Any`

The password of the database_user.

Default value: `$zabbix::params::server_database_password`

##### <a name="-zabbix--database--database_host"></a>`database_host`

Data type: `Any`

The hostname of the server running the database.

Default value: `$zabbix::params::server_database_host`

##### <a name="-zabbix--database--database_host_ip"></a>`database_host_ip`

Data type: `Any`

IP of the machine the database runs on.

Default value: `$zabbix::params::server_database_host_ip`

##### <a name="-zabbix--database--database_charset"></a>`database_charset`

Data type: `Any`

The default charset of the database.

Default value: `$zabbix::params::server_database_charset`

##### <a name="-zabbix--database--database_collate"></a>`database_collate`

Data type: `Any`

The default collation of the database.

Default value: `$zabbix::params::server_database_collate`

##### <a name="-zabbix--database--database_tablespace"></a>`database_tablespace`

Data type: `Optional[String[1]]`

The tablespace the database will be created in. This setting only affects PostgreSQL databases.

Default value: `$zabbix::params::server_database_tablespace`

### <a name="zabbix--database--sqlite"></a>`zabbix::database::sqlite`

Class to handle sqlite database installations zabbix will automatically create a sqlite schema if one does not already exist.

### <a name="zabbix--javagateway"></a>`zabbix::javagateway`

This will install and configure the zabbix-agent deamon

#### Examples

##### 

```puppet
class { 'zabbix::javagateway':
  zabbix_version => '6.0',
}
```

#### Parameters

The following parameters are available in the `zabbix::javagateway` class:

* [`zabbix_version`](#-zabbix--javagateway--zabbix_version)
* [`zabbix_package_state`](#-zabbix--javagateway--zabbix_package_state)
* [`manage_firewall`](#-zabbix--javagateway--manage_firewall)
* [`manage_repo`](#-zabbix--javagateway--manage_repo)
* [`pidfile`](#-zabbix--javagateway--pidfile)
* [`listenip`](#-zabbix--javagateway--listenip)
* [`listenport`](#-zabbix--javagateway--listenport)
* [`startpollers`](#-zabbix--javagateway--startpollers)
* [`timeout`](#-zabbix--javagateway--timeout)

##### <a name="-zabbix--javagateway--zabbix_version"></a>`zabbix_version`

Data type: `Any`

This is the zabbix version.

Default value: `$zabbix::params::zabbix_version`

##### <a name="-zabbix--javagateway--zabbix_package_state"></a>`zabbix_package_state`

Data type: `Any`

The state of the package that needs to be installed: present or latest.

Default value: `$zabbix::params::zabbix_package_state`

##### <a name="-zabbix--javagateway--manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

When true, it will create iptables rules.

Default value: `$zabbix::params::manage_firewall`

##### <a name="-zabbix--javagateway--manage_repo"></a>`manage_repo`

Data type: `Boolean`

When true, it will create repository for installing the javagateway.

Default value: `$zabbix::params::manage_repo`

##### <a name="-zabbix--javagateway--pidfile"></a>`pidfile`

Data type: `Any`

Name of pid file.

Default value: `$zabbix::params::javagateway_pidfile`

##### <a name="-zabbix--javagateway--listenip"></a>`listenip`

Data type: `Any`

List of comma delimited ip addresses that the agent should listen on.

Default value: `$zabbix::params::javagateway_listenip`

##### <a name="-zabbix--javagateway--listenport"></a>`listenport`

Data type: `Any`

Agent will listen on this port for connections from the server.

Default value: `$zabbix::params::javagateway_listenport`

##### <a name="-zabbix--javagateway--startpollers"></a>`startpollers`

Data type: `Any`

Number of worker threads to start.

Default value: `$zabbix::params::javagateway_startpollers`

##### <a name="-zabbix--javagateway--timeout"></a>`timeout`

Data type: `Any`

Number of worker threads to start.

Default value: `$zabbix::params::javagateway_timeout`

### <a name="zabbix--params"></a>`zabbix::params`

This class manages zabbix server parameters

### <a name="zabbix--proxy"></a>`zabbix::proxy`

This will install and configure the zabbix-proxy deamon

#### Examples

##### When you want to run everything on one machine, you can use the following:

```puppet
class { 'zabbix::proxy':
  zabbix_server_host => '192.168.1.1',
  zabbix_server_port => '10051',
}
```

##### When you want to use mysql:

```puppet
class { 'zabbix::proxy':
  zabbix_server_host => '192.168.1.1',
  zabbix_server_port => '10051',
  database_type      => 'mysql',
}
```

##### The following is an example of running the proxy on 2 servers:

```puppet
node 'wdpuppet03.dj-wasabi.local' {
  #class { 'postgresql::client': }
  class { 'mysql::client': }
  class { 'zabbix::proxy':
    zabbix_server_host => '192.168.1.1',
    manage_database    => false,
    database_host      => 'wdpuppet04.dj-wasabi.local',
    database_type      => 'mysql',
  }
}

node 'wdpuppet04.dj-wasabi.local' {
  #class { 'postgresql::server':
  #    listen_addresses => '192.168.20.14'
  #  }
    class { 'mysql::server':
      override_options => {
        'mysqld'       => {
          'bind_address' => '192.168.20.14',
        },
      },
    }
  class { 'zabbix::database':
    database_type     => 'mysql',
    zabbix_type       => 'proxy',
    #zabbix_proxy_ip   => '192.168.20.13',
    zabbix_proxy      => 'wdpuppet03.dj-wasabi.local',
    database_name     => 'zabbix-proxy',
    database_user     => 'zabbix-proxy',
    database_password => 'zabbix-proxy',
  }
}
```

#### Parameters

The following parameters are available in the `zabbix::proxy` class:

* [`database_type`](#-zabbix--proxy--database_type)
* [`database_path`](#-zabbix--proxy--database_path)
* [`zabbix_version`](#-zabbix--proxy--zabbix_version)
* [`zabbix_package_state`](#-zabbix--proxy--zabbix_package_state)
* [`manage_database`](#-zabbix--proxy--manage_database)
* [`manage_firewall`](#-zabbix--proxy--manage_firewall)
* [`manage_repo`](#-zabbix--proxy--manage_repo)
* [`manage_resources`](#-zabbix--proxy--manage_resources)
* [`manage_service`](#-zabbix--proxy--manage_service)
* [`zabbix_proxy`](#-zabbix--proxy--zabbix_proxy)
* [`zabbix_proxy_ip`](#-zabbix--proxy--zabbix_proxy_ip)
* [`use_ip`](#-zabbix--proxy--use_ip)
* [`zbx_templates`](#-zabbix--proxy--zbx_templates)
* [`proxy_configfile_path`](#-zabbix--proxy--proxy_configfile_path)
* [`proxy_service_name`](#-zabbix--proxy--proxy_service_name)
* [`mode`](#-zabbix--proxy--mode)
* [`zabbix_server_host`](#-zabbix--proxy--zabbix_server_host)
* [`zabbix_server_port`](#-zabbix--proxy--zabbix_server_port)
* [`hostname`](#-zabbix--proxy--hostname)
* [`listenport`](#-zabbix--proxy--listenport)
* [`sourceip`](#-zabbix--proxy--sourceip)
* [`enableremotecommands`](#-zabbix--proxy--enableremotecommands)
* [`logremotecommands`](#-zabbix--proxy--logremotecommands)
* [`logfile`](#-zabbix--proxy--logfile)
* [`logfilesize`](#-zabbix--proxy--logfilesize)
* [`logtype`](#-zabbix--proxy--logtype)
* [`debuglevel`](#-zabbix--proxy--debuglevel)
* [`pidfile`](#-zabbix--proxy--pidfile)
* [`database_schema_path`](#-zabbix--proxy--database_schema_path)
* [`database_host`](#-zabbix--proxy--database_host)
* [`database_name`](#-zabbix--proxy--database_name)
* [`database_schema`](#-zabbix--proxy--database_schema)
* [`database_user`](#-zabbix--proxy--database_user)
* [`database_password`](#-zabbix--proxy--database_password)
* [`database_socket`](#-zabbix--proxy--database_socket)
* [`database_port`](#-zabbix--proxy--database_port)
* [`database_charset`](#-zabbix--proxy--database_charset)
* [`database_collate`](#-zabbix--proxy--database_collate)
* [`database_tlsconnect`](#-zabbix--proxy--database_tlsconnect)
* [`database_tlscafile`](#-zabbix--proxy--database_tlscafile)
* [`database_tlscertfile`](#-zabbix--proxy--database_tlscertfile)
* [`database_tlskeyfile`](#-zabbix--proxy--database_tlskeyfile)
* [`database_tlscipher`](#-zabbix--proxy--database_tlscipher)
* [`database_tlscipher13`](#-zabbix--proxy--database_tlscipher13)
* [`localbuffer`](#-zabbix--proxy--localbuffer)
* [`offlinebuffer`](#-zabbix--proxy--offlinebuffer)
* [`heartbeatfrequency`](#-zabbix--proxy--heartbeatfrequency)
* [`configfrequency`](#-zabbix--proxy--configfrequency)
* [`proxyconfigfrequency`](#-zabbix--proxy--proxyconfigfrequency)
* [`datasenderfrequency`](#-zabbix--proxy--datasenderfrequency)
* [`startpollers`](#-zabbix--proxy--startpollers)
* [`startpreprocessors`](#-zabbix--proxy--startpreprocessors)
* [`startipmipollers`](#-zabbix--proxy--startipmipollers)
* [`startodbcpollers`](#-zabbix--proxy--startodbcpollers)
* [`startpollersunreachable`](#-zabbix--proxy--startpollersunreachable)
* [`starttrappers`](#-zabbix--proxy--starttrappers)
* [`startpingers`](#-zabbix--proxy--startpingers)
* [`startdiscoverers`](#-zabbix--proxy--startdiscoverers)
* [`starthttppollers`](#-zabbix--proxy--starthttppollers)
* [`javagateway`](#-zabbix--proxy--javagateway)
* [`javagatewayport`](#-zabbix--proxy--javagatewayport)
* [`startjavapollers`](#-zabbix--proxy--startjavapollers)
* [`startvmwarecollectors`](#-zabbix--proxy--startvmwarecollectors)
* [`vmwarefrequency`](#-zabbix--proxy--vmwarefrequency)
* [`vmwareperffrequency`](#-zabbix--proxy--vmwareperffrequency)
* [`vmwaretimeout`](#-zabbix--proxy--vmwaretimeout)
* [`vmwarecachesize`](#-zabbix--proxy--vmwarecachesize)
* [`vaultdbpath`](#-zabbix--proxy--vaultdbpath)
* [`vaulttoken`](#-zabbix--proxy--vaulttoken)
* [`vaulturl`](#-zabbix--proxy--vaulturl)
* [`snmptrapperfile`](#-zabbix--proxy--snmptrapperfile)
* [`snmptrapper`](#-zabbix--proxy--snmptrapper)
* [`listenip`](#-zabbix--proxy--listenip)
* [`housekeepingfrequency`](#-zabbix--proxy--housekeepingfrequency)
* [`cachesize`](#-zabbix--proxy--cachesize)
* [`startdbsyncers`](#-zabbix--proxy--startdbsyncers)
* [`historycachesize`](#-zabbix--proxy--historycachesize)
* [`historyindexcachesize`](#-zabbix--proxy--historyindexcachesize)
* [`historytextcachesize`](#-zabbix--proxy--historytextcachesize)
* [`timeout`](#-zabbix--proxy--timeout)
* [`tlsaccept`](#-zabbix--proxy--tlsaccept)
* [`tlscafile`](#-zabbix--proxy--tlscafile)
* [`tlscertfile`](#-zabbix--proxy--tlscertfile)
* [`tlsconnect`](#-zabbix--proxy--tlsconnect)
* [`tlscrlfile`](#-zabbix--proxy--tlscrlfile)
* [`tlskeyfile`](#-zabbix--proxy--tlskeyfile)
* [`tlspskfile`](#-zabbix--proxy--tlspskfile)
* [`tlspskidentity`](#-zabbix--proxy--tlspskidentity)
* [`tlscipherall`](#-zabbix--proxy--tlscipherall)
* [`tlscipherall13`](#-zabbix--proxy--tlscipherall13)
* [`tlsciphercert`](#-zabbix--proxy--tlsciphercert)
* [`tlsciphercert13`](#-zabbix--proxy--tlsciphercert13)
* [`tlscipherpsk`](#-zabbix--proxy--tlscipherpsk)
* [`tlscipherpsk13`](#-zabbix--proxy--tlscipherpsk13)
* [`tlsservercertissuer`](#-zabbix--proxy--tlsservercertissuer)
* [`tlsservercertsubject`](#-zabbix--proxy--tlsservercertsubject)
* [`trappertimeout`](#-zabbix--proxy--trappertimeout)
* [`unreachableperiod`](#-zabbix--proxy--unreachableperiod)
* [`unavaliabledelay`](#-zabbix--proxy--unavaliabledelay)
* [`unreachabedelay`](#-zabbix--proxy--unreachabedelay)
* [`externalscripts`](#-zabbix--proxy--externalscripts)
* [`fpinglocation`](#-zabbix--proxy--fpinglocation)
* [`fping6location`](#-zabbix--proxy--fping6location)
* [`sshkeylocation`](#-zabbix--proxy--sshkeylocation)
* [`statsallowedip`](#-zabbix--proxy--statsallowedip)
* [`sslcalocation_dir`](#-zabbix--proxy--sslcalocation_dir)
* [`sslcertlocation_dir`](#-zabbix--proxy--sslcertlocation_dir)
* [`sslkeylocation_dir`](#-zabbix--proxy--sslkeylocation_dir)
* [`logslowqueries`](#-zabbix--proxy--logslowqueries)
* [`tmpdir`](#-zabbix--proxy--tmpdir)
* [`allowroot`](#-zabbix--proxy--allowroot)
* [`include_dir`](#-zabbix--proxy--include_dir)
* [`loadmodulepath`](#-zabbix--proxy--loadmodulepath)
* [`loadmodule`](#-zabbix--proxy--loadmodule)
* [`manage_selinux`](#-zabbix--proxy--manage_selinux)
* [`socketdir`](#-zabbix--proxy--socketdir)

##### <a name="-zabbix--proxy--database_type"></a>`database_type`

Data type: `Zabbix::Databases`

Type of database. Can use the following 3 databases: postgresql, mysql, sqlite

Default value: `$zabbix::params::database_type`

##### <a name="-zabbix--proxy--database_path"></a>`database_path`

Data type: `Any`

When database binaries are not found on the default path:
/bin:/usr/bin:/usr/local/sbin:/usr/local/bin
you can use this parameter to add the database_path to the above mentiond
path.

Default value: `$zabbix::params::database_path`

##### <a name="-zabbix--proxy--zabbix_version"></a>`zabbix_version`

Data type: `Any`

This is the zabbix version.

Default value: `$zabbix::params::zabbix_version`

##### <a name="-zabbix--proxy--zabbix_package_state"></a>`zabbix_package_state`

Data type: `Any`

The state of the package that needs to be installed: present or latest.

Default value: `$zabbix::params::zabbix_package_state`

##### <a name="-zabbix--proxy--manage_database"></a>`manage_database`

Data type: `Boolean`

When true, it will configure the database and execute the sql scripts.

Default value: `$zabbix::params::manage_database`

##### <a name="-zabbix--proxy--manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

When true, it will create iptables rules.

Default value: `$zabbix::params::manage_firewall`

##### <a name="-zabbix--proxy--manage_repo"></a>`manage_repo`

Data type: `Boolean`

When true, it will create repository for installing the proxy.

Default value: `$zabbix::params::manage_repo`

##### <a name="-zabbix--proxy--manage_resources"></a>`manage_resources`

Data type: `Boolean`

When true, it will export resources so that the zabbix-server can create via the zabbix-api proxy.

Default value: `$zabbix::params::manage_resources`

##### <a name="-zabbix--proxy--manage_service"></a>`manage_service`

Data type: `Boolean`

When true, it will ensure service running and enabled.
When false, it does not care about service

Default value: `$zabbix::params::manage_service`

##### <a name="-zabbix--proxy--zabbix_proxy"></a>`zabbix_proxy`

Data type: `Any`

Hostname of zabbix proxy.

Default value: `$zabbix::params::zabbix_proxy`

##### <a name="-zabbix--proxy--zabbix_proxy_ip"></a>`zabbix_proxy_ip`

Data type: `Any`

IP of zabbix proxy.

Default value: `$zabbix::params::zabbix_proxy_ip`

##### <a name="-zabbix--proxy--use_ip"></a>`use_ip`

Data type: `Any`

When true, when creating proxies via the zabbix-api, it will configure that
connection should me made via ip, not fqdn.

Default value: `$zabbix::params::proxy_use_ip`

##### <a name="-zabbix--proxy--zbx_templates"></a>`zbx_templates`

Data type: `Any`

Template which will be added when proxy is configured.

Default value: `$zabbix::params::proxy_zbx_templates`

##### <a name="-zabbix--proxy--proxy_configfile_path"></a>`proxy_configfile_path`

Data type: `Any`

Proxy config file path defaults to /etc/zabbix/zabbix_proxy.conf

Default value: `$zabbix::params::proxy_configfile_path`

##### <a name="-zabbix--proxy--proxy_service_name"></a>`proxy_service_name`

Data type: `Any`

The service name of Zabbix proxy.

Default value: `$zabbix::params::proxy_service_name`

##### <a name="-zabbix--proxy--mode"></a>`mode`

Data type: `Any`

Proxy operating mode.

Default value: `$zabbix::params::proxy_mode`

##### <a name="-zabbix--proxy--zabbix_server_host"></a>`zabbix_server_host`

Data type: `Any`

Hostname or the ipaddress of the zabbix-server.

Default value: `$zabbix::params::proxy_zabbix_server_host`

##### <a name="-zabbix--proxy--zabbix_server_port"></a>`zabbix_server_port`

Data type: `Any`

Port on which the server is listening.

Default value: `$zabbix::params::proxy_zabbix_server_port`

##### <a name="-zabbix--proxy--hostname"></a>`hostname`

Data type: `Any`

Hostname for the proxy. Default is $::fqdn or this parameter.

Default value: `$zabbix::params::proxy_hostname`

##### <a name="-zabbix--proxy--listenport"></a>`listenport`

Data type: `Any`

Listen port for trapper.

Default value: `$zabbix::params::proxy_listenport`

##### <a name="-zabbix--proxy--sourceip"></a>`sourceip`

Data type: `Any`

Source ip address for outgoing connections.

Default value: `$zabbix::params::proxy_sourceip`

##### <a name="-zabbix--proxy--enableremotecommands"></a>`enableremotecommands`

Data type: `Integer[0]`

Whether remote commands from zabbix server are allowed.

Default value: `$zabbix::params::proxy_enableremotecommands`

##### <a name="-zabbix--proxy--logremotecommands"></a>`logremotecommands`

Data type: `Integer[0]`

Enable logging of executed shell commands as warnings.

Default value: `$zabbix::params::proxy_logremotecommands`

##### <a name="-zabbix--proxy--logfile"></a>`logfile`

Data type: `Optional[Stdlib::Absolutepath]`

Name of log file.

Default value: `$zabbix::params::proxy_logfile`

##### <a name="-zabbix--proxy--logfilesize"></a>`logfilesize`

Data type: `Any`

Maximum size of log file in MB.

Default value: `$zabbix::params::proxy_logfilesize`

##### <a name="-zabbix--proxy--logtype"></a>`logtype`

Data type: `Enum['console', 'file', 'system']`

Specifies where log messages are written to. Can be one of: console, file, system

Default value: `$zabbix::params::proxy_logtype`

##### <a name="-zabbix--proxy--debuglevel"></a>`debuglevel`

Data type: `Any`

Specifies debug level.

Default value: `$zabbix::params::proxy_debuglevel`

##### <a name="-zabbix--proxy--pidfile"></a>`pidfile`

Data type: `Any`

Name of pid file.

Default value: `$zabbix::params::proxy_pidfile`

##### <a name="-zabbix--proxy--database_schema_path"></a>`database_schema_path`

Data type: `Any`

The path to the directory containing the .sql schema files

Default value: `$zabbix::params::database_schema_path`

##### <a name="-zabbix--proxy--database_host"></a>`database_host`

Data type: `Any`

Database host name.

Default value: `$zabbix::params::proxy_database_host`

##### <a name="-zabbix--proxy--database_name"></a>`database_name`

Data type: `Any`

Database name.

Default value: `$zabbix::params::proxy_database_name`

##### <a name="-zabbix--proxy--database_schema"></a>`database_schema`

Data type: `Any`

Schema name. used for ibm db2.

Default value: `$zabbix::params::proxy_database_schema`

##### <a name="-zabbix--proxy--database_user"></a>`database_user`

Data type: `Any`

Database user. ignored for sqlite.

Default value: `$zabbix::params::proxy_database_user`

##### <a name="-zabbix--proxy--database_password"></a>`database_password`

Data type: `Any`

Database password. ignored for sqlite.

Default value: `$zabbix::params::proxy_database_password`

##### <a name="-zabbix--proxy--database_socket"></a>`database_socket`

Data type: `Any`

Path to mysql socket.

Default value: `$zabbix::params::proxy_database_socket`

##### <a name="-zabbix--proxy--database_port"></a>`database_port`

Data type: `Any`

Database port when not using local socket. Ignored for sqlite.

Default value: `$zabbix::params::proxy_database_port`

##### <a name="-zabbix--proxy--database_charset"></a>`database_charset`

Data type: `Any`

The default charset of the database.

Default value: `$zabbix::params::server_database_charset`

##### <a name="-zabbix--proxy--database_collate"></a>`database_collate`

Data type: `Any`

The default collation of the database.

Default value: `$zabbix::params::server_database_collate`

##### <a name="-zabbix--proxy--database_tlsconnect"></a>`database_tlsconnect`

Data type: `Optional[Enum['required', 'verify_ca', 'verify_full']]`

Available options:
* required - connect using TLS
* verify_ca - connect using TLS and verify certificate
* verify_full - connect using TLS, verify certificate and verify that database identity specified by DBHost matches its certificate

Default value: `$zabbix::params::proxy_database_tlsconnect`

##### <a name="-zabbix--proxy--database_tlscafile"></a>`database_tlscafile`

Data type: `Optional[Stdlib::Absolutepath]`

Full pathname of a file containing the top-level CA(s) certificates for database certificate verification.

Default value: `$zabbix::params::proxy_database_tlscafile`

##### <a name="-zabbix--proxy--database_tlscertfile"></a>`database_tlscertfile`

Data type: `Optional[Stdlib::Absolutepath]`

Full pathname of file containing Zabbix server certificate for authenticating to database.

Default value: `$zabbix::params::proxy_database_tlscertfile`

##### <a name="-zabbix--proxy--database_tlskeyfile"></a>`database_tlskeyfile`

Data type: `Optional[Stdlib::Absolutepath]`

Full pathname of file containing the private key for authenticating to database.

Default value: `$zabbix::params::proxy_database_tlskeyfile`

##### <a name="-zabbix--proxy--database_tlscipher"></a>`database_tlscipher`

Data type: `Optional[String[1]]`

The list of encryption ciphers that Zabbix server permits for TLS protocols up through TLSv1.2.

Default value: `$zabbix::params::proxy_database_tlscipher`

##### <a name="-zabbix--proxy--database_tlscipher13"></a>`database_tlscipher13`

Data type: `Optional[String[1]]`

The list of encryption ciphersuites that Zabbix server permits for TLSv1.3 protocol.

Default value: `$zabbix::params::proxy_database_tlscipher13`

##### <a name="-zabbix--proxy--localbuffer"></a>`localbuffer`

Data type: `Any`

Proxy will keep data locally for N hours, even if the data have already been synced with the server

Default value: `$zabbix::params::proxy_localbuffer`

##### <a name="-zabbix--proxy--offlinebuffer"></a>`offlinebuffer`

Data type: `Any`

Proxy will keep data for N hours in case if no connectivity with Zabbix Server

Default value: `$zabbix::params::proxy_offlinebuffer`

##### <a name="-zabbix--proxy--heartbeatfrequency"></a>`heartbeatfrequency`

Data type: `Any`

Unique nodeid in distributed setup.

Default value: `$zabbix::params::proxy_heartbeatfrequency`

##### <a name="-zabbix--proxy--configfrequency"></a>`configfrequency`

Data type: `Any`

How often proxy retrieves configuration data from Zabbix Server in seconds.

Default value: `$zabbix::params::proxy_configfrequency`

##### <a name="-zabbix--proxy--proxyconfigfrequency"></a>`proxyconfigfrequency`

Data type: `Optional[Integer[1,604800]]`

How often proxy retrieves configuration data from Zabbix Server in seconds (Zabbix 6.4).

Default value: `$zabbix::params::proxy_proxyconfigfrequency`

##### <a name="-zabbix--proxy--datasenderfrequency"></a>`datasenderfrequency`

Data type: `Any`

Proxy will send collected data to the Server every N seconds.

Default value: `$zabbix::params::proxy_datasenderfrequency`

##### <a name="-zabbix--proxy--startpollers"></a>`startpollers`

Data type: `Any`

Number of pre-forked instances of pollers.

Default value: `$zabbix::params::proxy_startpollers`

##### <a name="-zabbix--proxy--startpreprocessors"></a>`startpreprocessors`

Data type: `Integer[1, 1000]`

Number of pre-forked instances of preprocessing workers

Default value: `$zabbix::params::proxy_startpreprocessors`

##### <a name="-zabbix--proxy--startipmipollers"></a>`startipmipollers`

Data type: `Any`

Number of pre-forked instances of ipmi pollers.

Default value: `$zabbix::params::proxy_startipmipollers`

##### <a name="-zabbix--proxy--startodbcpollers"></a>`startodbcpollers`

Data type: `Integer[0, 1000]`

Number of pre-forked instances of ODBC pollers.

Default value: `$zabbix::params::proxy_startodbcpollers`

##### <a name="-zabbix--proxy--startpollersunreachable"></a>`startpollersunreachable`

Data type: `Any`

Number of pre-forked instances of pollers for unreachable hosts (including ipmi).

Default value: `$zabbix::params::proxy_startpollersunreachable`

##### <a name="-zabbix--proxy--starttrappers"></a>`starttrappers`

Data type: `Any`

Number of pre-forked instances of trappers.

Default value: `$zabbix::params::proxy_starttrappers`

##### <a name="-zabbix--proxy--startpingers"></a>`startpingers`

Data type: `Any`

Number of pre-forked instances of icmp pingers.

Default value: `$zabbix::params::proxy_startpingers`

##### <a name="-zabbix--proxy--startdiscoverers"></a>`startdiscoverers`

Data type: `Any`

Number of pre-forked instances of discoverers.

Default value: `$zabbix::params::proxy_startdiscoverers`

##### <a name="-zabbix--proxy--starthttppollers"></a>`starthttppollers`

Data type: `Any`

Number of pre-forked instances of http pollers.

Default value: `$zabbix::params::proxy_starthttppollers`

##### <a name="-zabbix--proxy--javagateway"></a>`javagateway`

Data type: `Any`

IP address (or hostname) of zabbix java gateway.

Default value: `$zabbix::params::proxy_javagateway`

##### <a name="-zabbix--proxy--javagatewayport"></a>`javagatewayport`

Data type: `Any`

Port that zabbix java gateway listens on.

Default value: `$zabbix::params::proxy_javagatewayport`

##### <a name="-zabbix--proxy--startjavapollers"></a>`startjavapollers`

Data type: `Any`

Number of pre-forked instances of java pollers.

Default value: `$zabbix::params::proxy_startjavapollers`

##### <a name="-zabbix--proxy--startvmwarecollectors"></a>`startvmwarecollectors`

Data type: `Any`

Number of pre-forked vmware collector instances.

Default value: `$zabbix::params::proxy_startvmwarecollectors`

##### <a name="-zabbix--proxy--vmwarefrequency"></a>`vmwarefrequency`

Data type: `Any`

How often zabbix will connect to vmware service to obtain a new datan.

Default value: `$zabbix::params::proxy_vmwarefrequency`

##### <a name="-zabbix--proxy--vmwareperffrequency"></a>`vmwareperffrequency`

Data type: `Any`

Delay in seconds between performance counter statistics retrieval from a single VMware service.
This delay should be set to the least update interval of any VMware monitoring item that uses VMware performance counters.

Default value: `$zabbix::params::proxy_vmwareperffrequency`

##### <a name="-zabbix--proxy--vmwaretimeout"></a>`vmwaretimeout`

Data type: `Any`

The maximum number of seconds vmware collector will wait for a response from VMware service (vCenter or ESX hypervisor).

Default value: `$zabbix::params::proxy_vmwaretimeout`

##### <a name="-zabbix--proxy--vmwarecachesize"></a>`vmwarecachesize`

Data type: `Any`

Size of vmware cache, in bytes.

Default value: `$zabbix::params::proxy_vmwarecachesize`

##### <a name="-zabbix--proxy--vaultdbpath"></a>`vaultdbpath`

Data type: `Optional[String[1]]`

Vault path from where credentials for database will be retrieved by keys 'password' and 'username'.

Default value: `$zabbix::params::proxy_vaultdbpath`

##### <a name="-zabbix--proxy--vaulttoken"></a>`vaulttoken`

Data type: `Optional[String[1]]`

Vault authentication token that should have been generated exclusively for Zabbix proxy with read-only
permission to the path specified in the optional VaultDBPath configuration parameter.

Default value: `$zabbix::params::proxy_vaulttoken`

##### <a name="-zabbix--proxy--vaulturl"></a>`vaulturl`

Data type: `Stdlib::HTTPSUrl`

Vault server HTTP[S] URL. System-wide CA certificates directory will be used if SSLCALocation is not specified.

Default value: `$zabbix::params::proxy_vaulturl`

##### <a name="-zabbix--proxy--snmptrapperfile"></a>`snmptrapperfile`

Data type: `Any`

Temporary file used for passing data from snmp trap daemon to the server.

Default value: `$zabbix::params::proxy_snmptrapperfile`

##### <a name="-zabbix--proxy--snmptrapper"></a>`snmptrapper`

Data type: `Any`

If 1, snmp trapper process is started.

Default value: `$zabbix::params::proxy_snmptrapper`

##### <a name="-zabbix--proxy--listenip"></a>`listenip`

Data type: `Any`

List of comma delimited ip addresses that the trapper should listen on.

Default value: `$zabbix::params::proxy_listenip`

##### <a name="-zabbix--proxy--housekeepingfrequency"></a>`housekeepingfrequency`

Data type: `Any`

How often Zabbix will perform housekeeping procedure (in hours).

Default value: `$zabbix::params::proxy_housekeepingfrequency`

##### <a name="-zabbix--proxy--cachesize"></a>`cachesize`

Data type: `Any`

Size of configuration cache, in MB.

Default value: `$zabbix::params::proxy_cachesize`

##### <a name="-zabbix--proxy--startdbsyncers"></a>`startdbsyncers`

Data type: `Any`

Number of pre-forked instances of db syncers.

Default value: `$zabbix::params::proxy_startdbsyncers`

##### <a name="-zabbix--proxy--historycachesize"></a>`historycachesize`

Data type: `Any`

Size of history cache, in bytes.

Default value: `$zabbix::params::proxy_historycachesize`

##### <a name="-zabbix--proxy--historyindexcachesize"></a>`historyindexcachesize`

Data type: `Any`

Size of history index cache, in bytes.

Default value: `$zabbix::params::proxy_historyindexcachesize`

##### <a name="-zabbix--proxy--historytextcachesize"></a>`historytextcachesize`

Data type: `Any`

Size of text history cache, in bytes.

Default value: `$zabbix::params::proxy_historytextcachesize`

##### <a name="-zabbix--proxy--timeout"></a>`timeout`

Data type: `Any`

Specifies how long we wait for agent, snmp device or external check (in seconds).

Default value: `$zabbix::params::proxy_timeout`

##### <a name="-zabbix--proxy--tlsaccept"></a>`tlsaccept`

Data type: `Any`

What incoming connections to accept from Zabbix server. Used for a passive proxy, ignored on an active proxy.

Default value: `$zabbix::params::proxy_tlsaccept`

##### <a name="-zabbix--proxy--tlscafile"></a>`tlscafile`

Data type: `Any`

Full pathname of a file containing the top-level CA(s) certificates for peer certificate verification.

Default value: `$zabbix::params::proxy_tlscafile`

##### <a name="-zabbix--proxy--tlscertfile"></a>`tlscertfile`

Data type: `Any`

Full pathname of a file containing the proxy certificate or certificate chain.

Default value: `$zabbix::params::proxy_tlscertfile`

##### <a name="-zabbix--proxy--tlsconnect"></a>`tlsconnect`

Data type: `Any`

How the proxy should connect to Zabbix server. Used for an active proxy, ignored on a passive proxy.

Default value: `$zabbix::params::proxy_tlsconnect`

##### <a name="-zabbix--proxy--tlscrlfile"></a>`tlscrlfile`

Data type: `Any`

Full pathname of a file containing revoked certificates.

Default value: `$zabbix::params::proxy_tlscrlfile`

##### <a name="-zabbix--proxy--tlskeyfile"></a>`tlskeyfile`

Data type: `Any`

Full pathname of a file containing the proxy private key.

Default value: `$zabbix::params::proxy_tlskeyfile`

##### <a name="-zabbix--proxy--tlspskfile"></a>`tlspskfile`

Data type: `Any`

Full pathname of a file containing the pre-shared key.

Default value: `$zabbix::params::proxy_tlspskfile`

##### <a name="-zabbix--proxy--tlspskidentity"></a>`tlspskidentity`

Data type: `Any`

Unique, case sensitive string used to identify the pre-shared key.

Default value: `$zabbix::params::proxy_tlspskidentity`

##### <a name="-zabbix--proxy--tlscipherall"></a>`tlscipherall`

Data type: `Optional[String[1]]`

GnuTLS priority string or OpenSSL (TLS 1.2) cipher string. Override the default ciphersuite selection criteria
for certificate- and PSK-based encryption.

Default value: `$zabbix::params::proxy_tlscipherall`

##### <a name="-zabbix--proxy--tlscipherall13"></a>`tlscipherall13`

Data type: `Optional[String[1]]`

Cipher string for OpenSSL 1.1.1 or newer in TLS 1.3. Override the default ciphersuite selection criteria
for certificate- and PSK-based encryption.

Default value: `$zabbix::params::proxy_tlscipherall13`

##### <a name="-zabbix--proxy--tlsciphercert"></a>`tlsciphercert`

Data type: `Optional[String[1]]`

GnuTLS priority string or OpenSSL (TLS 1.2) cipher string. Override the default ciphersuite selection criteria
for certificate-based encryption.

Default value: `$zabbix::params::proxy_tlsciphercert`

##### <a name="-zabbix--proxy--tlsciphercert13"></a>`tlsciphercert13`

Data type: `Optional[String[1]]`

Cipher string for OpenSSL 1.1.1 or newer in TLS 1.3. Override the default ciphersuite selection criteria
for certificate-based encryption.

Default value: `$zabbix::params::proxy_tlsciphercert13`

##### <a name="-zabbix--proxy--tlscipherpsk"></a>`tlscipherpsk`

Data type: `Optional[String[1]]`

GnuTLS priority string or OpenSSL (TLS 1.2) cipher string. Override the default ciphersuite selection criteria
for PSK-based encryption.

Default value: `$zabbix::params::proxy_tlscipherpsk`

##### <a name="-zabbix--proxy--tlscipherpsk13"></a>`tlscipherpsk13`

Data type: `Optional[String[1]]`

Cipher string for OpenSSL 1.1.1 or newer in TLS 1.3. Override the default ciphersuite selection criteria
for PSK-based encryption.

Default value: `$zabbix::params::proxy_tlscipherpsk13`

##### <a name="-zabbix--proxy--tlsservercertissuer"></a>`tlsservercertissuer`

Data type: `Any`

Allowed server certificate issuer.

Default value: `$zabbix::params::proxy_tlsservercertissuer`

##### <a name="-zabbix--proxy--tlsservercertsubject"></a>`tlsservercertsubject`

Data type: `Any`

Allowed server certificate subject.

Default value: `$zabbix::params::proxy_tlsservercertsubject`

##### <a name="-zabbix--proxy--trappertimeout"></a>`trappertimeout`

Data type: `Any`

Specifies how many seconds trapper may spend processing new data.

Default value: `$zabbix::params::proxy_trappertimeout`

##### <a name="-zabbix--proxy--unreachableperiod"></a>`unreachableperiod`

Data type: `Any`

After how many seconds of unreachability treat a host as unavailable.

Default value: `$zabbix::params::proxy_unreachableperiod`

##### <a name="-zabbix--proxy--unavaliabledelay"></a>`unavaliabledelay`

Data type: `Any`

How often host is checked for availability during the unavailability period, in seconds.

Default value: `$zabbix::params::proxy_unavaliabledelay`

##### <a name="-zabbix--proxy--unreachabedelay"></a>`unreachabedelay`

Data type: `Any`

How often host is checked for availability during the unreachability period, in seconds.

Default value: `$zabbix::params::proxy_unreachabedelay`

##### <a name="-zabbix--proxy--externalscripts"></a>`externalscripts`

Data type: `Any`

Full path to location of external scripts.

Default value: `$zabbix::params::proxy_externalscripts`

##### <a name="-zabbix--proxy--fpinglocation"></a>`fpinglocation`

Data type: `Any`

Location of fping.

Default value: `$zabbix::params::proxy_fpinglocation`

##### <a name="-zabbix--proxy--fping6location"></a>`fping6location`

Data type: `Any`

Location of fping6.

Default value: `$zabbix::params::proxy_fping6location`

##### <a name="-zabbix--proxy--sshkeylocation"></a>`sshkeylocation`

Data type: `Any`

Location of public and private keys for ssh checks and actions.

Default value: `$zabbix::params::proxy_sshkeylocation`

##### <a name="-zabbix--proxy--statsallowedip"></a>`statsallowedip`

Data type: `Optional[String[1]]`

list of allowed ipadresses that can access the internal stats of zabbix proxy over network

Default value: `$zabbix::params::proxy_statsallowedip`

##### <a name="-zabbix--proxy--sslcalocation_dir"></a>`sslcalocation_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Location of certificate authority (CA) files for SSL server certificate verification.

Default value: `$zabbix::params::proxy_sslcalocation`

##### <a name="-zabbix--proxy--sslcertlocation_dir"></a>`sslcertlocation_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Location of SSL client certificate files for client authentication.

Default value: `$zabbix::params::proxy_sslcertlocation`

##### <a name="-zabbix--proxy--sslkeylocation_dir"></a>`sslkeylocation_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Location of SSL private key files for client authentication.

Default value: `$zabbix::params::proxy_sslkeylocation`

##### <a name="-zabbix--proxy--logslowqueries"></a>`logslowqueries`

Data type: `Any`

How long a database query may take before being logged (in milliseconds).

Default value: `$zabbix::params::proxy_logslowqueries`

##### <a name="-zabbix--proxy--tmpdir"></a>`tmpdir`

Data type: `Any`

Temporary directory.

Default value: `$zabbix::params::proxy_tmpdir`

##### <a name="-zabbix--proxy--allowroot"></a>`allowroot`

Data type: `Any`

Allow the server to run as 'root'.

Default value: `$zabbix::params::proxy_allowroot`

##### <a name="-zabbix--proxy--include_dir"></a>`include_dir`

Data type: `Any`

You may include individual files or all files in a directory in the configuration file.

Default value: `$zabbix::params::proxy_include`

##### <a name="-zabbix--proxy--loadmodulepath"></a>`loadmodulepath`

Data type: `Any`

Full path to location of server modules.

Default value: `$zabbix::params::proxy_loadmodulepath`

##### <a name="-zabbix--proxy--loadmodule"></a>`loadmodule`

Data type: `Any`

Module to load at server startup.

Default value: `$zabbix::params::proxy_loadmodule`

##### <a name="-zabbix--proxy--manage_selinux"></a>`manage_selinux`

Data type: `Boolean`

Whether we should manage SELinux rules.

Default value: `$zabbix::params::manage_selinux`

##### <a name="-zabbix--proxy--socketdir"></a>`socketdir`

Data type: `Optional[Stdlib::Absolutepath]`

IPC socket directory. Directory to store IPC sockets used by internal Zabbix services.

Default value: `$zabbix::params::proxy_socketdir`

### <a name="zabbix--repo"></a>`zabbix::repo`

If enabled, this will install the repository used for installing zabbix

#### Parameters

The following parameters are available in the `zabbix::repo` class:

* [`manage_repo`](#-zabbix--repo--manage_repo)
* [`manage_apt`](#-zabbix--repo--manage_apt)
* [`zabbix_version`](#-zabbix--repo--zabbix_version)
* [`repo_location`](#-zabbix--repo--repo_location)
* [`frontend_repo_location`](#-zabbix--repo--frontend_repo_location)
* [`unsupported_repo_location`](#-zabbix--repo--unsupported_repo_location)

##### <a name="-zabbix--repo--manage_repo"></a>`manage_repo`

Data type: `Boolean`

When true, it will create repository for installing the server.

Default value: `$zabbix::params::manage_repo`

##### <a name="-zabbix--repo--manage_apt"></a>`manage_apt`

Data type: `Boolean`

Whether the module should manage apt repositories for Debian based systems.

Default value: `$zabbix::params::manage_apt`

##### <a name="-zabbix--repo--zabbix_version"></a>`zabbix_version`

Data type: `String[1]`

This is the zabbix version.

Default value: `$zabbix::params::zabbix_version`

##### <a name="-zabbix--repo--repo_location"></a>`repo_location`

Data type: `Optional[Stdlib::HTTPUrl]`

A custom repo location (e.g. your own mirror)

Default value: `$zabbix::params::repo_location`

##### <a name="-zabbix--repo--frontend_repo_location"></a>`frontend_repo_location`

Data type: `Optional[Stdlib::HTTPUrl]`

A custom repo location for frontend package.

Default value: `$zabbix::params::frontend_repo_location`

##### <a name="-zabbix--repo--unsupported_repo_location"></a>`unsupported_repo_location`

Data type: `Optional[Stdlib::HTTPUrl]`

A custom repo location for unsupported content (e.g. your own mirror)
Currently only supported under RedHat based systems.

Default value: `$zabbix::params::unsupported_repo_location`

### <a name="zabbix--resources--agent"></a>`zabbix::resources::agent`

This will create resources into puppetdb for automatically configuring agent into zabbix front-end.

#### Parameters

The following parameters are available in the `zabbix::resources::agent` class:

* [`hostname`](#-zabbix--resources--agent--hostname)
* [`ipaddress`](#-zabbix--resources--agent--ipaddress)
* [`use_ip`](#-zabbix--resources--agent--use_ip)
* [`port`](#-zabbix--resources--agent--port)
* [`groups`](#-zabbix--resources--agent--groups)
* [`group_create`](#-zabbix--resources--agent--group_create)
* [`templates`](#-zabbix--resources--agent--templates)
* [`macros`](#-zabbix--resources--agent--macros)
* [`proxy`](#-zabbix--resources--agent--proxy)
* [`interfacetype`](#-zabbix--resources--agent--interfacetype)
* [`interfacedetails`](#-zabbix--resources--agent--interfacedetails)
* [`tls_connect`](#-zabbix--resources--agent--tls_connect)
* [`tls_accept`](#-zabbix--resources--agent--tls_accept)
* [`tls_issuer`](#-zabbix--resources--agent--tls_issuer)
* [`tls_subject`](#-zabbix--resources--agent--tls_subject)

##### <a name="-zabbix--resources--agent--hostname"></a>`hostname`

Data type: `Any`

Hostname of the machine

Default value: `undef`

##### <a name="-zabbix--resources--agent--ipaddress"></a>`ipaddress`

Data type: `Any`

The IP address of the machine running zabbix agent.

Default value: `undef`

##### <a name="-zabbix--resources--agent--use_ip"></a>`use_ip`

Data type: `Any`

Use ipadress instead of dns to connect.

Default value: `undef`

##### <a name="-zabbix--resources--agent--port"></a>`port`

Data type: `Any`

The port that the zabbix agent is listening on.

Default value: `undef`

##### <a name="-zabbix--resources--agent--groups"></a>`groups`

Data type: `Array[String[1]]`

An array of groups the host belongs to.

Default value: `undef`

##### <a name="-zabbix--resources--agent--group_create"></a>`group_create`

Data type: `Any`

Whether to create hostgroup if missing.

Default value: `undef`

##### <a name="-zabbix--resources--agent--templates"></a>`templates`

Data type: `Any`

List of templates which should be attached to this host.

Default value: `undef`

##### <a name="-zabbix--resources--agent--macros"></a>`macros`

Data type: `Any`

Array of hashes (macros) which should be attached to this host.

Default value: `undef`

##### <a name="-zabbix--resources--agent--proxy"></a>`proxy`

Data type: `Any`

Whether it is monitored by an proxy or not.

Default value: `undef`

##### <a name="-zabbix--resources--agent--interfacetype"></a>`interfacetype`

Data type: `Any`

Internally used identifier for the host interface.

Default value: `1`

##### <a name="-zabbix--resources--agent--interfacedetails"></a>`interfacedetails`

Data type: `Variant[Array, Hash]`

Hash with interface details for SNMP when interface type is 2.

Default value: `[]`

##### <a name="-zabbix--resources--agent--tls_connect"></a>`tls_connect`

Data type: `Optional[Enum['unencrypted','psk','cert']]`

How the server must connect to the agent

Default value: `undef`

##### <a name="-zabbix--resources--agent--tls_accept"></a>`tls_accept`

Data type: `Optional[Enum['unencrypted','psk','cert']]`

How the agent can connect to the server

Default value: `undef`

##### <a name="-zabbix--resources--agent--tls_issuer"></a>`tls_issuer`

Data type: `Optional[String[1]]`

Issuer of the certificate that is allowed to talk with the serve

Default value: `undef`

##### <a name="-zabbix--resources--agent--tls_subject"></a>`tls_subject`

Data type: `Optional[String[1]]`

Subject of the certificate that is allowed to talk with the server

Default value: `undef`

### <a name="zabbix--resources--proxy"></a>`zabbix::resources::proxy`

This will create resources into puppetdb for automatically configuring proxy agent into zabbix front-end.

#### Parameters

The following parameters are available in the `zabbix::resources::proxy` class:

* [`hostname`](#-zabbix--resources--proxy--hostname)
* [`ipaddress`](#-zabbix--resources--proxy--ipaddress)
* [`use_ip`](#-zabbix--resources--proxy--use_ip)
* [`mode`](#-zabbix--resources--proxy--mode)
* [`port`](#-zabbix--resources--proxy--port)

##### <a name="-zabbix--resources--proxy--hostname"></a>`hostname`

Data type: `Any`

Hostname of the proxy.

Default value: `undef`

##### <a name="-zabbix--resources--proxy--ipaddress"></a>`ipaddress`

Data type: `Any`

The IP address of the machine running zabbix proxy.

Default value: `undef`

##### <a name="-zabbix--resources--proxy--use_ip"></a>`use_ip`

Data type: `Any`

Whether to use ipadress instead of dns to connect.

Default value: `undef`

##### <a name="-zabbix--resources--proxy--mode"></a>`mode`

Data type: `Any`

The kind of mode the proxy running. Active (0) or passive (1).

Default value: `undef`

##### <a name="-zabbix--resources--proxy--port"></a>`port`

Data type: `Any`

The port that the zabbix proxy is listening on.

Default value: `undef`

### <a name="zabbix--resources--web"></a>`zabbix::resources::web`

This will load all zabbix related items from the puppet database and uses the zabbixapi gem to add/configure hosts via the zabbix-api

#### Parameters

The following parameters are available in the `zabbix::resources::web` class:

* [`zabbix_url`](#-zabbix--resources--web--zabbix_url)
* [`zabbix_user`](#-zabbix--resources--web--zabbix_user)
* [`zabbix_pass`](#-zabbix--resources--web--zabbix_pass)
* [`apache_use_ssl`](#-zabbix--resources--web--apache_use_ssl)

##### <a name="-zabbix--resources--web--zabbix_url"></a>`zabbix_url`

Data type: `String[1]`

Url on which zabbix is available.

##### <a name="-zabbix--resources--web--zabbix_user"></a>`zabbix_user`

Data type: `String[1]`

API username.

##### <a name="-zabbix--resources--web--zabbix_pass"></a>`zabbix_pass`

Data type: `String[1]`

API password.

##### <a name="-zabbix--resources--web--apache_use_ssl"></a>`apache_use_ssl`

Data type: `Boolean`

Whether to use ssl or not.

### <a name="zabbix--sender"></a>`zabbix::sender`

This will install and configure the zabbix-agent deamon

#### Parameters

The following parameters are available in the `zabbix::sender` class:

* [`zabbix_version`](#-zabbix--sender--zabbix_version)
* [`zabbix_package_state`](#-zabbix--sender--zabbix_package_state)
* [`manage_repo`](#-zabbix--sender--manage_repo)

##### <a name="-zabbix--sender--zabbix_version"></a>`zabbix_version`

Data type: `Any`

This is the zabbix version.

Default value: `$zabbix::params::zabbix_version`

##### <a name="-zabbix--sender--zabbix_package_state"></a>`zabbix_package_state`

Data type: `Any`

The state of the package that needs to be installed: present or latest.

Default value: `$zabbix::params::zabbix_package_state`

##### <a name="-zabbix--sender--manage_repo"></a>`manage_repo`

Data type: `Any`

When true, it will create repository for installing the agent.

Default value: `$zabbix::params::manage_repo`

### <a name="zabbix--server"></a>`zabbix::server`

This will install and configure the zabbix-server deamon

#### Examples

##### 

```puppet
When running everything on a single node, please check
documentation in init.pp
The following is an example of an multiple host setup:

node 'wdpuppet03.dj-wasabi.local' {
  #class { 'postgresql::client': }
  class { 'mysql::client': }
  class { 'zabbix::server':
    zabbix_version => '2.4',
    database_host  => 'wdpuppet04.dj-wasabi.local',
    database_type  => 'mysql',
  }
}

The setup of above shows an configuration which used mysql as database.
It will require the database "client" classes, this is needed for executing
the installation files.

When database_type = postgres, uncomment the postgresql::client class and change or
remove the database_type parameter and comment the mysql::client class.
```

#### Parameters

The following parameters are available in the `zabbix::server` class:

* [`database_type`](#-zabbix--server--database_type)
* [`database_path`](#-zabbix--server--database_path)
* [`zabbix_version`](#-zabbix--server--zabbix_version)
* [`manage_repo`](#-zabbix--server--manage_repo)
* [`manage_database`](#-zabbix--server--manage_database)
* [`zabbix_package_state`](#-zabbix--server--zabbix_package_state)
* [`manage_firewall`](#-zabbix--server--manage_firewall)
* [`manage_service`](#-zabbix--server--manage_service)
* [`server_configfile_path`](#-zabbix--server--server_configfile_path)
* [`server_config_owner`](#-zabbix--server--server_config_owner)
* [`server_config_group`](#-zabbix--server--server_config_group)
* [`server_service_name`](#-zabbix--server--server_service_name)
* [`pacemaker`](#-zabbix--server--pacemaker)
* [`pacemaker_resource`](#-zabbix--server--pacemaker_resource)
* [`listenport`](#-zabbix--server--listenport)
* [`sourceip`](#-zabbix--server--sourceip)
* [`logfile`](#-zabbix--server--logfile)
* [`logfilesize`](#-zabbix--server--logfilesize)
* [`logtype`](#-zabbix--server--logtype)
* [`debuglevel`](#-zabbix--server--debuglevel)
* [`pidfile`](#-zabbix--server--pidfile)
* [`database_schema_path`](#-zabbix--server--database_schema_path)
* [`database_host`](#-zabbix--server--database_host)
* [`database_name`](#-zabbix--server--database_name)
* [`database_schema`](#-zabbix--server--database_schema)
* [`database_user`](#-zabbix--server--database_user)
* [`database_password`](#-zabbix--server--database_password)
* [`database_socket`](#-zabbix--server--database_socket)
* [`database_port`](#-zabbix--server--database_port)
* [`database_tlsconnect`](#-zabbix--server--database_tlsconnect)
* [`database_tlscafile`](#-zabbix--server--database_tlscafile)
* [`database_tlscertfile`](#-zabbix--server--database_tlscertfile)
* [`database_tlskeyfile`](#-zabbix--server--database_tlskeyfile)
* [`database_tlscipher`](#-zabbix--server--database_tlscipher)
* [`database_tlscipher13`](#-zabbix--server--database_tlscipher13)
* [`startpollers`](#-zabbix--server--startpollers)
* [`startpreprocessors`](#-zabbix--server--startpreprocessors)
* [`startipmipollers`](#-zabbix--server--startipmipollers)
* [`startodbcpollers`](#-zabbix--server--startodbcpollers)
* [`startpollersunreachable`](#-zabbix--server--startpollersunreachable)
* [`starttrappers`](#-zabbix--server--starttrappers)
* [`startpingers`](#-zabbix--server--startpingers)
* [`startalerters`](#-zabbix--server--startalerters)
* [`startdiscoverers`](#-zabbix--server--startdiscoverers)
* [`startescalators`](#-zabbix--server--startescalators)
* [`starthttppollers`](#-zabbix--server--starthttppollers)
* [`starttimers`](#-zabbix--server--starttimers)
* [`javagateway`](#-zabbix--server--javagateway)
* [`javagatewayport`](#-zabbix--server--javagatewayport)
* [`startjavapollers`](#-zabbix--server--startjavapollers)
* [`startlldprocessors`](#-zabbix--server--startlldprocessors)
* [`startvmwarecollectors`](#-zabbix--server--startvmwarecollectors)
* [`startreportwriters`](#-zabbix--server--startreportwriters)
* [`webserviceurl`](#-zabbix--server--webserviceurl)
* [`vmwarefrequency`](#-zabbix--server--vmwarefrequency)
* [`vaultdbpath`](#-zabbix--server--vaultdbpath)
* [`vaulttoken`](#-zabbix--server--vaulttoken)
* [`vaulturl`](#-zabbix--server--vaulturl)
* [`vmwarecachesize`](#-zabbix--server--vmwarecachesize)
* [`vmwaretimeout`](#-zabbix--server--vmwaretimeout)
* [`snmptrapperfile`](#-zabbix--server--snmptrapperfile)
* [`startsnmptrapper`](#-zabbix--server--startsnmptrapper)
* [`listenip`](#-zabbix--server--listenip)
* [`housekeepingfrequency`](#-zabbix--server--housekeepingfrequency)
* [`maxhousekeeperdelete`](#-zabbix--server--maxhousekeeperdelete)
* [`cachesize`](#-zabbix--server--cachesize)
* [`cacheupdatefrequency`](#-zabbix--server--cacheupdatefrequency)
* [`startdbsyncers`](#-zabbix--server--startdbsyncers)
* [`historycachesize`](#-zabbix--server--historycachesize)
* [`historyindexcachesize`](#-zabbix--server--historyindexcachesize)
* [`trendcachesize`](#-zabbix--server--trendcachesize)
* [`valuecachesize`](#-zabbix--server--valuecachesize)
* [`timeout`](#-zabbix--server--timeout)
* [`tlscafile`](#-zabbix--server--tlscafile)
* [`tlscertfile`](#-zabbix--server--tlscertfile)
* [`tlscrlfile`](#-zabbix--server--tlscrlfile)
* [`tlskeyfile`](#-zabbix--server--tlskeyfile)
* [`tlscipherall`](#-zabbix--server--tlscipherall)
* [`tlscipherall13`](#-zabbix--server--tlscipherall13)
* [`tlsciphercert`](#-zabbix--server--tlsciphercert)
* [`tlsciphercert13`](#-zabbix--server--tlsciphercert13)
* [`tlscipherpsk`](#-zabbix--server--tlscipherpsk)
* [`tlscipherpsk13`](#-zabbix--server--tlscipherpsk13)
* [`trappertimeout`](#-zabbix--server--trappertimeout)
* [`unreachableperiod`](#-zabbix--server--unreachableperiod)
* [`unavailabledelay`](#-zabbix--server--unavailabledelay)
* [`unreachabledelay`](#-zabbix--server--unreachabledelay)
* [`alertscriptspath`](#-zabbix--server--alertscriptspath)
* [`externalscripts`](#-zabbix--server--externalscripts)
* [`fpinglocation`](#-zabbix--server--fpinglocation)
* [`fping6location`](#-zabbix--server--fping6location)
* [`sshkeylocation`](#-zabbix--server--sshkeylocation)
* [`logslowqueries`](#-zabbix--server--logslowqueries)
* [`tmpdir`](#-zabbix--server--tmpdir)
* [`startproxypollers`](#-zabbix--server--startproxypollers)
* [`proxyconfigfrequency`](#-zabbix--server--proxyconfigfrequency)
* [`proxydatafrequency`](#-zabbix--server--proxydatafrequency)
* [`allowroot`](#-zabbix--server--allowroot)
* [`include_dir`](#-zabbix--server--include_dir)
* [`statsallowedip`](#-zabbix--server--statsallowedip)
* [`loadmodulepath`](#-zabbix--server--loadmodulepath)
* [`loadmodule`](#-zabbix--server--loadmodule)
* [`sslcertlocation_dir`](#-zabbix--server--sslcertlocation_dir)
* [`sslkeylocation_dir`](#-zabbix--server--sslkeylocation_dir)
* [`manage_selinux`](#-zabbix--server--manage_selinux)
* [`additional_service_params`](#-zabbix--server--additional_service_params)
* [`zabbix_user`](#-zabbix--server--zabbix_user)
* [`manage_startup_script`](#-zabbix--server--manage_startup_script)
* [`socketdir`](#-zabbix--server--socketdir)
* [`hanodename`](#-zabbix--server--hanodename)
* [`nodeaddress`](#-zabbix--server--nodeaddress)

##### <a name="-zabbix--server--database_type"></a>`database_type`

Data type: `Zabbix::Databases`

Type of database. Can use the following 2 databases:
- postgresql
- mysql

Default value: `$zabbix::params::database_type`

##### <a name="-zabbix--server--database_path"></a>`database_path`

Data type: `Any`

When database binaries are not found on the default path:
/bin:/usr/bin:/usr/local/sbin:/usr/local/bin
you can use this parameter to add the database_path to the above mentioned
path.

Default value: `$zabbix::params::database_path`

##### <a name="-zabbix--server--zabbix_version"></a>`zabbix_version`

Data type: `Any`

This is the zabbix version. Example: 5.0

Default value: `$zabbix::params::zabbix_version`

##### <a name="-zabbix--server--manage_repo"></a>`manage_repo`

Data type: `Boolean`

When true (default) this module will manage the Zabbix repository.

Default value: `$zabbix::params::manage_repo`

##### <a name="-zabbix--server--manage_database"></a>`manage_database`

Data type: `Boolean`

When true, it will configure the database and execute the sql scripts.

Default value: `$zabbix::params::manage_database`

##### <a name="-zabbix--server--zabbix_package_state"></a>`zabbix_package_state`

Data type: `Any`

The state of the package that needs to be installed: present or latest.

Default value: `$zabbix::params::zabbix_package_state`

##### <a name="-zabbix--server--manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

When true, it will create iptables rules.

Default value: `$zabbix::params::manage_firewall`

##### <a name="-zabbix--server--manage_service"></a>`manage_service`

Data type: `Boolean`

When true, it will ensure service running and enabled.
When false, it does not care about service

Default value: `$zabbix::params::manage_service`

##### <a name="-zabbix--server--server_configfile_path"></a>`server_configfile_path`

Data type: `Any`

Server config file path defaults to /etc/zabbix/zabbix_server.conf

Default value: `$zabbix::params::server_configfile_path`

##### <a name="-zabbix--server--server_config_owner"></a>`server_config_owner`

Data type: `Any`

The owner of Zabbix's server config file.

Default value: `$zabbix::params::server_config_owner`

##### <a name="-zabbix--server--server_config_group"></a>`server_config_group`

Data type: `Any`

The group of Zabbix's server config file.

Default value: `$zabbix::params::server_config_group`

##### <a name="-zabbix--server--server_service_name"></a>`server_service_name`

Data type: `Any`

The service name of Zabbix server.

Default value: `$zabbix::params::server_service_name`

##### <a name="-zabbix--server--pacemaker"></a>`pacemaker`

Data type: `Any`

Whether to control zabbix server through Pacemaker.

Default value: `$zabbix::params::server_pacemaker`

##### <a name="-zabbix--server--pacemaker_resource"></a>`pacemaker_resource`

Data type: `Any`

Zabbix server pacemaker resource.

Default value: `$zabbix::params::server_pacemaker_resource`

##### <a name="-zabbix--server--listenport"></a>`listenport`

Data type: `Any`

Listen port for the zabbix-server. Default: 10051

Default value: `$zabbix::params::server_listenport`

##### <a name="-zabbix--server--sourceip"></a>`sourceip`

Data type: `Any`

Source ip address for outgoing connections.

Default value: `$zabbix::params::server_sourceip`

##### <a name="-zabbix--server--logfile"></a>`logfile`

Data type: `Optional[Stdlib::Absolutepath]`

Name of log file.

Default value: `$zabbix::params::server_logfile`

##### <a name="-zabbix--server--logfilesize"></a>`logfilesize`

Data type: `Any`

Maximum size of log file in MB.

Default value: `$zabbix::params::server_logfilesize`

##### <a name="-zabbix--server--logtype"></a>`logtype`

Data type: `Enum['console', 'file', 'system']`

Specifies where log messages are written to. (options: console, file, system)

Default value: `$zabbix::params::server_logtype`

##### <a name="-zabbix--server--debuglevel"></a>`debuglevel`

Data type: `Any`

Specifies debug level.

Default value: `$zabbix::params::server_debuglevel`

##### <a name="-zabbix--server--pidfile"></a>`pidfile`

Data type: `Any`

Name of pid file.

Default value: `$zabbix::params::server_pidfile`

##### <a name="-zabbix--server--database_schema_path"></a>`database_schema_path`

Data type: `Any`

The path to the directory containing the .sql schema files

Default value: `$zabbix::params::database_schema_path`

##### <a name="-zabbix--server--database_host"></a>`database_host`

Data type: `Any`

Database host name.

Default value: `$zabbix::params::server_database_host`

##### <a name="-zabbix--server--database_name"></a>`database_name`

Data type: `Any`

Database name.

Default value: `$zabbix::params::server_database_name`

##### <a name="-zabbix--server--database_schema"></a>`database_schema`

Data type: `Any`

Schema name. used for ibm db2.

Default value: `$zabbix::params::server_database_schema`

##### <a name="-zabbix--server--database_user"></a>`database_user`

Data type: `Any`

Database user. ignored for sqlite.

Default value: `$zabbix::params::server_database_user`

##### <a name="-zabbix--server--database_password"></a>`database_password`

Data type: `Any`

Database password. ignored for sqlite.

Default value: `$zabbix::params::server_database_password`

##### <a name="-zabbix--server--database_socket"></a>`database_socket`

Data type: `Any`

Path to mysql socket.

Default value: `$zabbix::params::server_database_socket`

##### <a name="-zabbix--server--database_port"></a>`database_port`

Data type: `Optional[Stdlib::Port::Unprivileged]`

Database port when not using local socket. Ignored for sqlite.

Default value: `$zabbix::params::server_database_port`

##### <a name="-zabbix--server--database_tlsconnect"></a>`database_tlsconnect`

Data type: `Optional[Enum['required', 'verify_ca', 'verify_full']]`

Available options:
* required - connect using TLS
* verify_ca - connect using TLS and verify certificate
* verify_full - connect using TLS, verify certificate and verify that database identity specified by DBHost matches its certificate

Default value: `$zabbix::params::server_database_tlsconnect`

##### <a name="-zabbix--server--database_tlscafile"></a>`database_tlscafile`

Data type: `Optional[Stdlib::Absolutepath]`

Full pathname of a file containing the top-level CA(s) certificates for database certificate verification.

Default value: `$zabbix::params::server_database_tlscafile`

##### <a name="-zabbix--server--database_tlscertfile"></a>`database_tlscertfile`

Data type: `Optional[Stdlib::Absolutepath]`

Full pathname of file containing Zabbix server certificate for authenticating to database.

Default value: `$zabbix::params::server_database_tlscertfile`

##### <a name="-zabbix--server--database_tlskeyfile"></a>`database_tlskeyfile`

Data type: `Optional[Stdlib::Absolutepath]`

Full pathname of file containing the private key for authenticating to database.

Default value: `$zabbix::params::server_database_tlskeyfile`

##### <a name="-zabbix--server--database_tlscipher"></a>`database_tlscipher`

Data type: `Optional[String[1]]`

The list of encryption ciphers that Zabbix server permits for TLS protocols up through TLSv1.2.

Default value: `$zabbix::params::server_database_tlscipher`

##### <a name="-zabbix--server--database_tlscipher13"></a>`database_tlscipher13`

Data type: `Optional[String[1]]`

The list of encryption ciphersuites that Zabbix server permits for TLSv1.3 protocol.

Default value: `$zabbix::params::server_database_tlscipher13`

##### <a name="-zabbix--server--startpollers"></a>`startpollers`

Data type: `Any`

Number of pre-forked instances of pollers.

Default value: `$zabbix::params::server_startpollers`

##### <a name="-zabbix--server--startpreprocessors"></a>`startpreprocessors`

Data type: `Integer[1, 1000]`

Number of pre-forked instances of preprocessing workers

Default value: `$zabbix::params::server_startpreprocessors`

##### <a name="-zabbix--server--startipmipollers"></a>`startipmipollers`

Data type: `Any`

Number of pre-forked instances of ipmi pollers.

Default value: `$zabbix::params::server_startipmipollers`

##### <a name="-zabbix--server--startodbcpollers"></a>`startodbcpollers`

Data type: `Integer[0, 1000]`

Number of pre-forked instances of ODBC pollers.

Default value: `$zabbix::params::server_startodbcpollers`

##### <a name="-zabbix--server--startpollersunreachable"></a>`startpollersunreachable`

Data type: `Any`

Number of pre-forked instances of pollers for unreachable hosts (including ipmi).

Default value: `$zabbix::params::server_startpollersunreachable`

##### <a name="-zabbix--server--starttrappers"></a>`starttrappers`

Data type: `Any`

Number of pre-forked instances of trappers.

Default value: `$zabbix::params::server_starttrappers`

##### <a name="-zabbix--server--startpingers"></a>`startpingers`

Data type: `Any`

Number of pre-forked instances of icmp pingers.

Default value: `$zabbix::params::server_startpingers`

##### <a name="-zabbix--server--startalerters"></a>`startalerters`

Data type: `Integer[1, 100]`

Number of pre-forked instances of alerters.

Default value: `$zabbix::params::server_startalerters`

##### <a name="-zabbix--server--startdiscoverers"></a>`startdiscoverers`

Data type: `Any`

Number of pre-forked instances of discoverers.

Default value: `$zabbix::params::server_startdiscoverers`

##### <a name="-zabbix--server--startescalators"></a>`startescalators`

Data type: `Integer[1, 100]`

Number of pre-forked instances of escalators.

Default value: `$zabbix::params::server_startescalators`

##### <a name="-zabbix--server--starthttppollers"></a>`starthttppollers`

Data type: `Any`

Number of pre-forked instances of http pollers.

Default value: `$zabbix::params::server_starthttppollers`

##### <a name="-zabbix--server--starttimers"></a>`starttimers`

Data type: `Any`

Number of pre-forked instances of timers.

Default value: `$zabbix::params::server_starttimers`

##### <a name="-zabbix--server--javagateway"></a>`javagateway`

Data type: `Any`

IP address (or hostname) of zabbix java gateway.

Default value: `$zabbix::params::server_javagateway`

##### <a name="-zabbix--server--javagatewayport"></a>`javagatewayport`

Data type: `Any`

Port that zabbix java gateway listens on.

Default value: `$zabbix::params::server_javagatewayport`

##### <a name="-zabbix--server--startjavapollers"></a>`startjavapollers`

Data type: `Any`

Number of pre-forked instances of java pollers.

Default value: `$zabbix::params::server_startjavapollers`

##### <a name="-zabbix--server--startlldprocessors"></a>`startlldprocessors`

Data type: `Integer[1, 100]`

Number of pre-forked instances of low-level discovery (LLD) workers.

Default value: `$zabbix::params::server_startlldprocessors`

##### <a name="-zabbix--server--startvmwarecollectors"></a>`startvmwarecollectors`

Data type: `Any`

Number of pre-forked vmware collector instances.

Default value: `$zabbix::params::server_startvmwarecollectors`

##### <a name="-zabbix--server--startreportwriters"></a>`startreportwriters`

Data type: `Optional[Integer[1, 100]]`

Number of pre-forked report writer instances.

Default value: `undef`

##### <a name="-zabbix--server--webserviceurl"></a>`webserviceurl`

Data type: `Optional[Stdlib::HTTPUrl]`

URL to Zabbix web service, used to perform web related tasks.

Default value: `undef`

##### <a name="-zabbix--server--vmwarefrequency"></a>`vmwarefrequency`

Data type: `Any`

How often zabbix will connect to vmware service to obtain a new datan.

Default value: `$zabbix::params::server_vmwarefrequency`

##### <a name="-zabbix--server--vaultdbpath"></a>`vaultdbpath`

Data type: `Optional[String[1]]`

Vault path from where credentials for database will be retrieved by keys 'password' and 'username'.

Default value: `$zabbix::params::server_vaultdbpath`

##### <a name="-zabbix--server--vaulttoken"></a>`vaulttoken`

Data type: `Optional[String[1]]`

Vault authentication token that should have been generated exclusively for Zabbix proxy with read-only
permission to the path specified in the optional VaultDBPath configuration parameter.

Default value: `$zabbix::params::server_vaulttoken`

##### <a name="-zabbix--server--vaulturl"></a>`vaulturl`

Data type: `Stdlib::HTTPSUrl`

Vault server HTTP[S] URL. System-wide CA certificates directory will be used if SSLCALocation is not specified.

Default value: `$zabbix::params::server_vaulturl`

##### <a name="-zabbix--server--vmwarecachesize"></a>`vmwarecachesize`

Data type: `Any`

Size of vmware cache, in bytes.

Default value: `$zabbix::params::server_vmwarecachesize`

##### <a name="-zabbix--server--vmwaretimeout"></a>`vmwaretimeout`

Data type: `Any`

The maximum number of seconds vmware collector will wait for a response from VMware service.

Default value: `$zabbix::params::server_vmwaretimeout`

##### <a name="-zabbix--server--snmptrapperfile"></a>`snmptrapperfile`

Data type: `Any`

Temporary file used for passing data from snmp trap daemon to the server.

Default value: `$zabbix::params::server_snmptrapperfile`

##### <a name="-zabbix--server--startsnmptrapper"></a>`startsnmptrapper`

Data type: `Any`

If 1, snmp trapper process is started.

Default value: `$zabbix::params::server_startsnmptrapper`

##### <a name="-zabbix--server--listenip"></a>`listenip`

Data type: `Any`

List of comma delimited ip addresses that the zabbix-server should listen on.

Default value: `$zabbix::params::server_listenip`

##### <a name="-zabbix--server--housekeepingfrequency"></a>`housekeepingfrequency`

Data type: `Any`

How often zabbix will perform housekeeping procedure (in hours).

Default value: `$zabbix::params::server_housekeepingfrequency`

##### <a name="-zabbix--server--maxhousekeeperdelete"></a>`maxhousekeeperdelete`

Data type: `Any`

the table "housekeeper" contains "tasks" for housekeeping procedure in the format:
[housekeeperid], [tablename], [field], [value].
no more than 'maxhousekeeperdelete' rows (corresponding to [tablename], [field], [value])
will be deleted per one task in one housekeeping cycle.
sqlite3 does not use this parameter, deletes all corresponding rows without a limit.
if set to 0 then no limit is used at all. in this case you must know what you are doing!

Default value: `$zabbix::params::server_maxhousekeeperdelete`

##### <a name="-zabbix--server--cachesize"></a>`cachesize`

Data type: `Any`

Size of configuration cache, in bytes.

Default value: `$zabbix::params::server_cachesize`

##### <a name="-zabbix--server--cacheupdatefrequency"></a>`cacheupdatefrequency`

Data type: `Any`

How often zabbix will perform update of configuration cache, in seconds.

Default value: `$zabbix::params::server_cacheupdatefrequency`

##### <a name="-zabbix--server--startdbsyncers"></a>`startdbsyncers`

Data type: `Any`

Number of pre-forked instances of db syncers.

Default value: `$zabbix::params::server_startdbsyncers`

##### <a name="-zabbix--server--historycachesize"></a>`historycachesize`

Data type: `Any`

Size of history cache, in bytes.

Default value: `$zabbix::params::server_historycachesize`

##### <a name="-zabbix--server--historyindexcachesize"></a>`historyindexcachesize`

Data type: `Any`

Size of history index cache, in bytes.

Default value: `$zabbix::params::server_historyindexcachesize`

##### <a name="-zabbix--server--trendcachesize"></a>`trendcachesize`

Data type: `Any`

Size of trend cache, in bytes.

Default value: `$zabbix::params::server_trendcachesize`

##### <a name="-zabbix--server--valuecachesize"></a>`valuecachesize`

Data type: `Any`

Size of history value cache, in bytes.

Default value: `$zabbix::params::server_valuecachesize`

##### <a name="-zabbix--server--timeout"></a>`timeout`

Data type: `Any`

Specifies how long we wait for agent, snmp device or external check (in seconds).

Default value: `$zabbix::params::server_timeout`

##### <a name="-zabbix--server--tlscafile"></a>`tlscafile`

Data type: `Any`

Full pathname of a file containing the top-level CA(s) certificates for peer certificate verification.

Default value: `$zabbix::params::server_tlscafile`

##### <a name="-zabbix--server--tlscertfile"></a>`tlscertfile`

Data type: `Any`

Full pathname of a file containing the server certificate or certificate chain.

Default value: `$zabbix::params::server_tlscertfile`

##### <a name="-zabbix--server--tlscrlfile"></a>`tlscrlfile`

Data type: `Any`

Full pathname of a file containing revoked certificates.

Default value: `$zabbix::params::server_tlscrlfile`

##### <a name="-zabbix--server--tlskeyfile"></a>`tlskeyfile`

Data type: `Any`

Full pathname of a file containing the server private key.

Default value: `$zabbix::params::server_tlskeyfile`

##### <a name="-zabbix--server--tlscipherall"></a>`tlscipherall`

Data type: `Optional[String[1]]`

GnuTLS priority string or OpenSSL (TLS 1.2) cipher string. Override the default ciphersuite selection criteria
for certificate- and PSK-based encryption.

Default value: `$zabbix::params::server_tlscipherall`

##### <a name="-zabbix--server--tlscipherall13"></a>`tlscipherall13`

Data type: `Optional[String[1]]`

Cipher string for OpenSSL 1.1.1 or newer in TLS 1.3. Override the default ciphersuite selection criteria
for certificate- and PSK-based encryption.

Default value: `$zabbix::params::server_tlscipherall13`

##### <a name="-zabbix--server--tlsciphercert"></a>`tlsciphercert`

Data type: `Optional[String[1]]`

GnuTLS priority string or OpenSSL (TLS 1.2) cipher string. Override the default ciphersuite selection criteria
for certificate-based encryption.

Default value: `$zabbix::params::server_tlsciphercert`

##### <a name="-zabbix--server--tlsciphercert13"></a>`tlsciphercert13`

Data type: `Optional[String[1]]`

Cipher string for OpenSSL 1.1.1 or newer in TLS 1.3. Override the default ciphersuite selection criteria
for certificate-based encryption.

Default value: `$zabbix::params::server_tlsciphercert13`

##### <a name="-zabbix--server--tlscipherpsk"></a>`tlscipherpsk`

Data type: `Optional[String[1]]`

GnuTLS priority string or OpenSSL (TLS 1.2) cipher string. Override the default ciphersuite selection criteria
for PSK-based encryption.

Default value: `$zabbix::params::server_tlscipherpsk`

##### <a name="-zabbix--server--tlscipherpsk13"></a>`tlscipherpsk13`

Data type: `Optional[String[1]]`

Cipher string for OpenSSL 1.1.1 or newer in TLS 1.3. Override the default ciphersuite selection criteria
for PSK-based encryption.

Default value: `$zabbix::params::server_tlscipherpsk13`

##### <a name="-zabbix--server--trappertimeout"></a>`trappertimeout`

Data type: `Any`

Specifies how many seconds trapper may spend processing new data.

Default value: `$zabbix::params::server_trappertimeout`

##### <a name="-zabbix--server--unreachableperiod"></a>`unreachableperiod`

Data type: `Any`

After how many seconds of unreachability treat a host as unavailable.

Default value: `$zabbix::params::server_unreachableperiod`

##### <a name="-zabbix--server--unavailabledelay"></a>`unavailabledelay`

Data type: `Any`

How often host is checked for availability during the unavailability period, in seconds.

Default value: `$zabbix::params::server_unavailabledelay`

##### <a name="-zabbix--server--unreachabledelay"></a>`unreachabledelay`

Data type: `Any`

How often host is checked for availability during the unreachability period, in seconds.

Default value: `$zabbix::params::server_unreachabledelay`

##### <a name="-zabbix--server--alertscriptspath"></a>`alertscriptspath`

Data type: `Any`

Full path to location of custom alert scripts.

Default value: `$zabbix::params::server_alertscriptspath`

##### <a name="-zabbix--server--externalscripts"></a>`externalscripts`

Data type: `Any`

Full path to location of external scripts.

Default value: `$zabbix::params::server_externalscripts`

##### <a name="-zabbix--server--fpinglocation"></a>`fpinglocation`

Data type: `Any`

Location of fping.

Default value: `$zabbix::params::server_fpinglocation`

##### <a name="-zabbix--server--fping6location"></a>`fping6location`

Data type: `Any`

Location of fping6.

Default value: `$zabbix::params::server_fping6location`

##### <a name="-zabbix--server--sshkeylocation"></a>`sshkeylocation`

Data type: `Any`

Location of public and private keys for ssh checks and actions.

Default value: `$zabbix::params::server_sshkeylocation`

##### <a name="-zabbix--server--logslowqueries"></a>`logslowqueries`

Data type: `Any`

How long a database query may take before being logged (in milliseconds).

Default value: `$zabbix::params::server_logslowqueries`

##### <a name="-zabbix--server--tmpdir"></a>`tmpdir`

Data type: `Any`

Temporary directory.

Default value: `$zabbix::params::server_tmpdir`

##### <a name="-zabbix--server--startproxypollers"></a>`startproxypollers`

Data type: `Any`

Number of pre-forked instances of pollers for passive proxies.

Default value: `$zabbix::params::server_startproxypollers`

##### <a name="-zabbix--server--proxyconfigfrequency"></a>`proxyconfigfrequency`

Data type: `Any`

How often zabbix server sends configuration data to a zabbix proxy in seconds.

Default value: `$zabbix::params::server_proxyconfigfrequency`

##### <a name="-zabbix--server--proxydatafrequency"></a>`proxydatafrequency`

Data type: `Any`

How often zabbix server requests history data from a zabbix proxy in seconds.

Default value: `$zabbix::params::server_proxydatafrequency`

##### <a name="-zabbix--server--allowroot"></a>`allowroot`

Data type: `Any`

Allow the server to run as 'root'.

Default value: `$zabbix::params::server_allowroot`

##### <a name="-zabbix--server--include_dir"></a>`include_dir`

Data type: `Any`

You may include individual files or all files in a directory in the configuration file.

Default value: `$zabbix::params::server_include`

##### <a name="-zabbix--server--statsallowedip"></a>`statsallowedip`

Data type: `Optional[String[1]]`

list of allowed ipadresses that can access the internal stats of zabbix server over network

Default value: `$zabbix::params::server_statsallowedip`

##### <a name="-zabbix--server--loadmodulepath"></a>`loadmodulepath`

Data type: `Any`

Full path to location of server modules.

Default value: `$zabbix::params::server_loadmodulepath`

##### <a name="-zabbix--server--loadmodule"></a>`loadmodule`

Data type: `Any`

Module to load at server startup.

Default value: `$zabbix::params::server_loadmodule`

##### <a name="-zabbix--server--sslcertlocation_dir"></a>`sslcertlocation_dir`

Data type: `Any`

Location of SSL client certificate files for client authentication.

Default value: `$zabbix::params::server_sslcertlocation`

##### <a name="-zabbix--server--sslkeylocation_dir"></a>`sslkeylocation_dir`

Data type: `Any`

Location of SSL private key files for client authentication.

Default value: `$zabbix::params::server_sslkeylocation`

##### <a name="-zabbix--server--manage_selinux"></a>`manage_selinux`

Data type: `Boolean`

Whether we should manage SELinux rules.

Default value: `$zabbix::params::manage_selinux`

##### <a name="-zabbix--server--additional_service_params"></a>`additional_service_params`

Data type: `String`

Additional parameters to pass to the service.

Default value: `$zabbix::params::additional_service_params`

##### <a name="-zabbix--server--zabbix_user"></a>`zabbix_user`

Data type: `Optional[String[1]]`

User the zabbix service will run as.

Default value: `$zabbix::params::server_zabbix_user`

##### <a name="-zabbix--server--manage_startup_script"></a>`manage_startup_script`

Data type: `Boolean`

If the init script should be managed by this module. Attention: This might cause problems with some config options of this module (e.g server_configfile_path)

Default value: `$zabbix::params::manage_startup_script`

##### <a name="-zabbix--server--socketdir"></a>`socketdir`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: `$zabbix::params::server_socketdir`

##### <a name="-zabbix--server--hanodename"></a>`hanodename`

Data type: `Optional[String[1]]`

Node name identifier in HA setup

Default value: `$zabbix::params::server_hanodename`

##### <a name="-zabbix--server--nodeaddress"></a>`nodeaddress`

Data type: `Optional[String[1]]`

Connection details to the HA node, used to check if zabbix-web can talk to zabbix server
IPC socket directory.
Directory to store IPC sockets used by internal Zabbix services.

Default value: `$zabbix::params::server_nodeaddress`

### <a name="zabbix--userparameter"></a>`zabbix::userparameter`

This class can be used when you use hiera or The Foreman. With this tools you can't use and define. This make use of "create_resources".

#### Examples

##### 

```puppet
zabbix::userparameter::data:
  MySQL:
    content: UserParameter=mysql.ping,mysqladmin -uroot ping | grep -c alive
```

#### Parameters

The following parameters are available in the `zabbix::userparameter` class:

* [`data`](#-zabbix--userparameter--data)

##### <a name="-zabbix--userparameter--data"></a>`data`

Data type: `Hash`

This is the data in YAML format

Default value: `{}`

### <a name="zabbix--web"></a>`zabbix::web`

This will install the zabbix-web package and install an virtual host.

#### Examples

##### For multiple host setup:

```puppet
node 'wdpuppet02.dj-wasabi.local' {
  class { 'apache':
      mpm_module => 'prefork',
  }
  class { 'zabbix::web':
    zabbix_url    => 'zabbix.dj-wasabi.nl',
    zabbix_server => 'wdpuppet03.dj-wasabi.local',
    database_host => 'wdpuppet04.dj-wasabi.local',
    database_type => 'mysql',
    puppetgem     => 'gem',
  }
}
```

#### Parameters

The following parameters are available in the `zabbix::web` class:

* [`zabbix_url`](#-zabbix--web--zabbix_url)
* [`database_type`](#-zabbix--web--database_type)
* [`manage_repo`](#-zabbix--web--manage_repo)
* [`zabbix_version`](#-zabbix--web--zabbix_version)
* [`zabbix_timezone`](#-zabbix--web--zabbix_timezone)
* [`zabbix_template_dir`](#-zabbix--web--zabbix_template_dir)
* [`zabbix_package_state`](#-zabbix--web--zabbix_package_state)
* [`web_config_owner`](#-zabbix--web--web_config_owner)
* [`web_config_group`](#-zabbix--web--web_config_group)
* [`manage_vhost`](#-zabbix--web--manage_vhost)
* [`default_vhost`](#-zabbix--web--default_vhost)
* [`manage_resources`](#-zabbix--web--manage_resources)
* [`apache_use_ssl`](#-zabbix--web--apache_use_ssl)
* [`apache_ssl_cert`](#-zabbix--web--apache_ssl_cert)
* [`apache_ssl_key`](#-zabbix--web--apache_ssl_key)
* [`apache_ssl_cipher`](#-zabbix--web--apache_ssl_cipher)
* [`apache_ssl_chain`](#-zabbix--web--apache_ssl_chain)
* [`apache_listen_ip`](#-zabbix--web--apache_listen_ip)
* [`apache_listenport`](#-zabbix--web--apache_listenport)
* [`apache_listenport_ssl`](#-zabbix--web--apache_listenport_ssl)
* [`zabbix_api_user`](#-zabbix--web--zabbix_api_user)
* [`zabbix_api_pass`](#-zabbix--web--zabbix_api_pass)
* [`zabbix_api_access`](#-zabbix--web--zabbix_api_access)
* [`database_host`](#-zabbix--web--database_host)
* [`database_name`](#-zabbix--web--database_name)
* [`database_schema`](#-zabbix--web--database_schema)
* [`database_double_ieee754`](#-zabbix--web--database_double_ieee754)
* [`database_user`](#-zabbix--web--database_user)
* [`database_password`](#-zabbix--web--database_password)
* [`database_socket`](#-zabbix--web--database_socket)
* [`database_port`](#-zabbix--web--database_port)
* [`zabbix_server`](#-zabbix--web--zabbix_server)
* [`zabbix_server_name`](#-zabbix--web--zabbix_server_name)
* [`zabbix_listenport`](#-zabbix--web--zabbix_listenport)
* [`apache_php_max_execution_time`](#-zabbix--web--apache_php_max_execution_time)
* [`apache_php_memory_limit`](#-zabbix--web--apache_php_memory_limit)
* [`apache_php_post_max_size`](#-zabbix--web--apache_php_post_max_size)
* [`apache_php_upload_max_filesize`](#-zabbix--web--apache_php_upload_max_filesize)
* [`apache_php_max_input_time`](#-zabbix--web--apache_php_max_input_time)
* [`apache_php_always_populate_raw_post_data`](#-zabbix--web--apache_php_always_populate_raw_post_data)
* [`apache_php_max_input_vars`](#-zabbix--web--apache_php_max_input_vars)
* [`ldap_cacert`](#-zabbix--web--ldap_cacert)
* [`ldap_clientcert`](#-zabbix--web--ldap_clientcert)
* [`ldap_clientkey`](#-zabbix--web--ldap_clientkey)
* [`ldap_reqcert`](#-zabbix--web--ldap_reqcert)
* [`saml_sp_key`](#-zabbix--web--saml_sp_key)
* [`saml_sp_cert`](#-zabbix--web--saml_sp_cert)
* [`saml_idp_cert`](#-zabbix--web--saml_idp_cert)
* [`saml_settings`](#-zabbix--web--saml_settings)
* [`puppetgem`](#-zabbix--web--puppetgem)
* [`manage_selinux`](#-zabbix--web--manage_selinux)
* [`apache_vhost_custom_params`](#-zabbix--web--apache_vhost_custom_params)

##### <a name="-zabbix--web--zabbix_url"></a>`zabbix_url`

Data type: `Any`

Url on which zabbix needs to be available. Will create an vhost in
apache. Only needed when manage_vhost is set to true.
Example: zabbix.example.com

Default value: `$zabbix::params::zabbix_url`

##### <a name="-zabbix--web--database_type"></a>`database_type`

Data type: `Any`

Type of database. Can use the following 2 databases:
- postgresql
- mysql

Default value: `$zabbix::params::database_type`

##### <a name="-zabbix--web--manage_repo"></a>`manage_repo`

Data type: `Any`

When true, it will create repository for installing the webinterface.

Default value: `$zabbix::params::manage_repo`

##### <a name="-zabbix--web--zabbix_version"></a>`zabbix_version`

Data type: `Any`

This is the zabbix version.

Default value: `$zabbix::params::zabbix_version`

##### <a name="-zabbix--web--zabbix_timezone"></a>`zabbix_timezone`

Data type: `Any`

The current timezone for vhost configuration needed for the php timezone. Example: Europe/Amsterdam

Default value: `$zabbix::params::zabbix_timezone`

##### <a name="-zabbix--web--zabbix_template_dir"></a>`zabbix_template_dir`

Data type: `Any`

The directory where all templates are stored before uploading via API

Default value: `$zabbix::params::zabbix_template_dir`

##### <a name="-zabbix--web--zabbix_package_state"></a>`zabbix_package_state`

Data type: `Any`

The state of the package that needs to be installed: present or latest.

Default value: `$zabbix::params::zabbix_package_state`

##### <a name="-zabbix--web--web_config_owner"></a>`web_config_owner`

Data type: `Any`

Which user should own the web interface configuration file.

Default value: `$zabbix::params::web_config_owner`

##### <a name="-zabbix--web--web_config_group"></a>`web_config_group`

Data type: `Any`

Which group should own the web interface configuration file.

Default value: `$zabbix::params::web_config_group`

##### <a name="-zabbix--web--manage_vhost"></a>`manage_vhost`

Data type: `Any`

When true, it will create an vhost for apache. The parameter zabbix_url has to be set.

Default value: `$zabbix::params::manage_vhost`

##### <a name="-zabbix--web--default_vhost"></a>`default_vhost`

Data type: `Any`

When true priority of 15 is passed to zabbix vhost which would end up
with marking zabbix vhost as default one, when false priority is set to 25

Default value: `$zabbix::params::default_vhost`

##### <a name="-zabbix--web--manage_resources"></a>`manage_resources`

Data type: `Any`

When true, it will export resources to something like puppetdb.
When set to true, you'll need to configure 'storeconfigs' to make
this happen. Default is set to false, as not everyone has this
enabled.

Default value: `$zabbix::params::manage_resources`

##### <a name="-zabbix--web--apache_use_ssl"></a>`apache_use_ssl`

Data type: `Any`

Will create an ssl vhost. Also nonssl vhost will be created for redirect
nonssl to ssl vhost.

Default value: `$zabbix::params::apache_use_ssl`

##### <a name="-zabbix--web--apache_ssl_cert"></a>`apache_ssl_cert`

Data type: `Any`

The location of the ssl certificate file. You'll need to make sure this
file is present on the system, this module will not install this file.

Default value: `$zabbix::params::apache_ssl_cert`

##### <a name="-zabbix--web--apache_ssl_key"></a>`apache_ssl_key`

Data type: `Any`

The location of the ssl key file. You'll need to make sure this file is
present on the system, this module will not install this file.

Default value: `$zabbix::params::apache_ssl_key`

##### <a name="-zabbix--web--apache_ssl_cipher"></a>`apache_ssl_cipher`

Data type: `Any`

The ssl cipher used. Cipher is used from this website:
https://wiki.mozilla.org/Security/Server_Side_TLS

Default value: `$zabbix::params::apache_ssl_cipher`

##### <a name="-zabbix--web--apache_ssl_chain"></a>`apache_ssl_chain`

Data type: `Any`

The ssl chain file.

Default value: `$zabbix::params::apache_ssl_chain`

##### <a name="-zabbix--web--apache_listen_ip"></a>`apache_listen_ip`

Data type: `Any`

The IP the apache service should listen on.

Default value: `$zabbix::params::apache_listen_ip`

##### <a name="-zabbix--web--apache_listenport"></a>`apache_listenport`

Data type: `Variant[Array[Stdlib::Port], Stdlib::Port]`

The port for the apache vhost.

Default value: `$zabbix::params::apache_listenport`

##### <a name="-zabbix--web--apache_listenport_ssl"></a>`apache_listenport_ssl`

Data type: `Variant[Array[Stdlib::Port], Stdlib::Port]`

The port for the apache SSL vhost.

Default value: `$zabbix::params::apache_listenport_ssl`

##### <a name="-zabbix--web--zabbix_api_user"></a>`zabbix_api_user`

Data type: `Any`

Name of the user which the api should connect to. Default: Admin

Default value: `$zabbix::params::server_api_user`

##### <a name="-zabbix--web--zabbix_api_pass"></a>`zabbix_api_pass`

Data type: `Any`

Password of the user which connects to the api. Default: zabbix

Default value: `$zabbix::params::server_api_pass`

##### <a name="-zabbix--web--zabbix_api_access"></a>`zabbix_api_access`

Data type: `Optional[Array[Stdlib::Host,1]]`

Which host has access to the api. Default: no restriction

Default value: `$zabbix::params::server_api_access`

##### <a name="-zabbix--web--database_host"></a>`database_host`

Data type: `Any`

Database host name.

Default value: `$zabbix::params::server_database_host`

##### <a name="-zabbix--web--database_name"></a>`database_name`

Data type: `Any`

Database name.

Default value: `$zabbix::params::server_database_name`

##### <a name="-zabbix--web--database_schema"></a>`database_schema`

Data type: `Any`

Schema name. used for ibm db2.

Default value: `$zabbix::params::server_database_schema`

##### <a name="-zabbix--web--database_double_ieee754"></a>`database_double_ieee754`

Data type: `Boolean`

Enable extended range of float values for new installs of Zabbix >= 5.0 and
after patching upgraded installs to 5.0 or greater.
https://www.zabbix.com/documentation/5.0/manual/installation/upgrade_notes_500#enabling_extended_range_of_numeric_float_values

Default value: `$zabbix::params::server_database_double_ieee754`

##### <a name="-zabbix--web--database_user"></a>`database_user`

Data type: `Any`

Database user. ignored for sqlite.

Default value: `$zabbix::params::server_database_user`

##### <a name="-zabbix--web--database_password"></a>`database_password`

Data type: `Any`

Database password. ignored for sqlite.

Default value: `$zabbix::params::server_database_password`

##### <a name="-zabbix--web--database_socket"></a>`database_socket`

Data type: `Any`

Path to mysql socket.

Default value: `$zabbix::params::server_database_socket`

##### <a name="-zabbix--web--database_port"></a>`database_port`

Data type: `Any`

Database port when not using local socket. Ignored for sqlite.

Default value: `$zabbix::params::server_database_port`

##### <a name="-zabbix--web--zabbix_server"></a>`zabbix_server`

Data type: `Any`

The fqdn name of the host running the zabbix-server. When single node: localhost

Default value: `$zabbix::params::zabbix_server`

##### <a name="-zabbix--web--zabbix_server_name"></a>`zabbix_server_name`

Data type: `Optional[String]`

The fqdn name of the host running the zabbix-server. When single node:
localhost
This can also be used to upave a different name such as "Zabbix DEV"

Default value: `$zabbix::params::zabbix_server`

##### <a name="-zabbix--web--zabbix_listenport"></a>`zabbix_listenport`

Data type: `Any`

The port on which the zabbix-server is listening. Default: 10051

Default value: `$zabbix::params::server_listenport`

##### <a name="-zabbix--web--apache_php_max_execution_time"></a>`apache_php_max_execution_time`

Data type: `Any`

Max execution time for php. Default: 300

Default value: `$zabbix::params::apache_php_max_execution_time`

##### <a name="-zabbix--web--apache_php_memory_limit"></a>`apache_php_memory_limit`

Data type: `Any`

PHP memory size limit. Default: 128M

Default value: `$zabbix::params::apache_php_memory_limit`

##### <a name="-zabbix--web--apache_php_post_max_size"></a>`apache_php_post_max_size`

Data type: `Any`

PHP maximum post size data. Default: 16M

Default value: `$zabbix::params::apache_php_post_max_size`

##### <a name="-zabbix--web--apache_php_upload_max_filesize"></a>`apache_php_upload_max_filesize`

Data type: `Any`

PHP maximum upload filesize. Default: 2M

Default value: `$zabbix::params::apache_php_upload_max_filesize`

##### <a name="-zabbix--web--apache_php_max_input_time"></a>`apache_php_max_input_time`

Data type: `Any`

Max input time for php. Default: 300

Default value: `$zabbix::params::apache_php_max_input_time`

##### <a name="-zabbix--web--apache_php_always_populate_raw_post_data"></a>`apache_php_always_populate_raw_post_data`

Data type: `Any`

Default: -1

Default value: `$zabbix::params::apache_php_always_populate_raw_post_data`

##### <a name="-zabbix--web--apache_php_max_input_vars"></a>`apache_php_max_input_vars`

Data type: `Any`

Max amount of vars for GET/POST requests

Default value: `$zabbix::params::apache_php_max_input_vars`

##### <a name="-zabbix--web--ldap_cacert"></a>`ldap_cacert`

Data type: `Optional[Stdlib::Absolutepath]`

Set location of ca_cert used by LDAP authentication.

Default value: `$zabbix::params::ldap_cacert`

##### <a name="-zabbix--web--ldap_clientcert"></a>`ldap_clientcert`

Data type: `Optional[Stdlib::Absolutepath]`

Set location of client cert used by LDAP authentication.

Default value: `$zabbix::params::ldap_clientcert`

##### <a name="-zabbix--web--ldap_clientkey"></a>`ldap_clientkey`

Data type: `Optional[Stdlib::Absolutepath]`

Set location of client key used by LDAP authentication.

Default value: `$zabbix::params::ldap_clientkey`

##### <a name="-zabbix--web--ldap_reqcert"></a>`ldap_reqcert`

Data type: `Optional[Enum['never','allow','try','demand','hard']]`

Specifies what checks to perform on a server certificate

Default value: `$zabbix::params::ldap_reqcert`

##### <a name="-zabbix--web--saml_sp_key"></a>`saml_sp_key`

Data type: `Optional[Stdlib::Absolutepath]`

The location of the SAML Service Provider Key file.

Default value: `$zabbix::params::saml_sp_key`

##### <a name="-zabbix--web--saml_sp_cert"></a>`saml_sp_cert`

Data type: `Optional[Stdlib::Absolutepath]`

The location of the SAML Service Provider Certificate.

Default value: `$zabbix::params::saml_sp_cert`

##### <a name="-zabbix--web--saml_idp_cert"></a>`saml_idp_cert`

Data type: `Optional[Stdlib::Absolutepath]`

The location of the SAML Identity Provider Certificate.

Default value: `$zabbix::params::saml_idp_cert`

##### <a name="-zabbix--web--saml_settings"></a>`saml_settings`

Data type: `Hash[String[1], Variant[ScalarData, Hash]]`

A hash of additional SAML SSO settings.

Default value: `$zabbix::params::saml_settings`

##### <a name="-zabbix--web--puppetgem"></a>`puppetgem`

Data type: `Any`

Provider for the zabbixapi gem package.

Default value: `$zabbix::params::puppetgem`

##### <a name="-zabbix--web--manage_selinux"></a>`manage_selinux`

Data type: `Boolean`

Whether we should manage SELinux rules.

Default value: `$zabbix::params::manage_selinux`

##### <a name="-zabbix--web--apache_vhost_custom_params"></a>`apache_vhost_custom_params`

Data type: `Hash[String[1], Any]`

Additional parameters to pass to apache::vhost.

Default value: `{}`

### <a name="zabbix--zabbixapi"></a>`zabbix::zabbixapi`

This will install the zabbixapi gem.

#### Parameters

The following parameters are available in the `zabbix::zabbixapi` class:

* [`zabbix_version`](#-zabbix--zabbixapi--zabbix_version)
* [`puppetgem`](#-zabbix--zabbixapi--puppetgem)

##### <a name="-zabbix--zabbixapi--zabbix_version"></a>`zabbix_version`

Data type: `Any`

This is the zabbix version.

Default value: `$zabbix::params::zabbix_version`

##### <a name="-zabbix--zabbixapi--puppetgem"></a>`puppetgem`

Data type: `Any`

Provider for the zabbixapi gem package.

Default value: `$zabbix::params::puppetgem`

### <a name="zabbix--zapache"></a>`zabbix::zapache`

This will install and configure the zapache monitoring script Upstream: https://github.com/lorf/zapache

#### Examples

##### Basic installation:

```puppet
class { 'zabbix::agent':
  manage_resources => true,
  apache_status    => true,
  zbx_templates    => [ 'Template App Apache Web Server zapache'],
}
```

#### Parameters

The following parameters are available in the `zabbix::zapache` class:

* [`apache_status`](#-zabbix--zapache--apache_status)

##### <a name="-zabbix--zapache--apache_status"></a>`apache_status`

Data type: `Boolean`

Boolean. False by default. Installs zapache monitoring script when true.

Default value: `$zabbix::params::apache_status`

## Defined types

### <a name="zabbix--resources--template"></a>`zabbix::resources::template`

This will create resources into puppetdb for automatically configuring agent into zabbix front-end.

#### Parameters

The following parameters are available in the `zabbix::resources::template` defined type:

* [`template_dir`](#-zabbix--resources--template--template_dir)
* [`template_name`](#-zabbix--resources--template--template_name)
* [`template_source`](#-zabbix--resources--template--template_source)
* [`zabbix_version`](#-zabbix--resources--template--zabbix_version)
* [`delete_missing_applications`](#-zabbix--resources--template--delete_missing_applications)
* [`delete_missing_drules`](#-zabbix--resources--template--delete_missing_drules)
* [`delete_missing_graphs`](#-zabbix--resources--template--delete_missing_graphs)
* [`delete_missing_httptests`](#-zabbix--resources--template--delete_missing_httptests)
* [`delete_missing_items`](#-zabbix--resources--template--delete_missing_items)
* [`delete_missing_templatescreens`](#-zabbix--resources--template--delete_missing_templatescreens)
* [`delete_missing_triggers`](#-zabbix--resources--template--delete_missing_triggers)

##### <a name="-zabbix--resources--template--template_dir"></a>`template_dir`

Data type: `Any`

The directory containing zabbix templates

Default value: `$zabbix::params::zabbix_template_dir`

##### <a name="-zabbix--resources--template--template_name"></a>`template_name`

Data type: `Any`

The name of template.

Default value: `$title`

##### <a name="-zabbix--resources--template--template_source"></a>`template_source`

Data type: `Any`

Template source file.

Default value: `''`

##### <a name="-zabbix--resources--template--zabbix_version"></a>`zabbix_version`

Data type: `Any`

Zabbix version that the template will be installed on.

Default value: `$zabbix::params::zabbix_version`

##### <a name="-zabbix--resources--template--delete_missing_applications"></a>`delete_missing_applications`

Data type: `Boolean`

Deletes applications from zabbix that are not in the template when set to true

Default value: `false`

##### <a name="-zabbix--resources--template--delete_missing_drules"></a>`delete_missing_drules`

Data type: `Boolean`

Deletes discovery rules from zabbix that are not in the template when set to true

Default value: `false`

##### <a name="-zabbix--resources--template--delete_missing_graphs"></a>`delete_missing_graphs`

Data type: `Boolean`

Deletes graphs from zabbix that are not in the template when set to true

Default value: `false`

##### <a name="-zabbix--resources--template--delete_missing_httptests"></a>`delete_missing_httptests`

Data type: `Boolean`

Deletes web-scenarios from zabbix that are not in the template when set to true

Default value: `false`

##### <a name="-zabbix--resources--template--delete_missing_items"></a>`delete_missing_items`

Data type: `Boolean`

Deletes items from zabbix that are not in the template when set to true

Default value: `false`

##### <a name="-zabbix--resources--template--delete_missing_templatescreens"></a>`delete_missing_templatescreens`

Data type: `Boolean`

Deletes template-screens from zabbix that are not in the template when set to true

Default value: `false`

##### <a name="-zabbix--resources--template--delete_missing_triggers"></a>`delete_missing_triggers`

Data type: `Boolean`

Deletes triggers from zabbix that are not in the template when set to true

Default value: `false`

### <a name="zabbix--resources--userparameters"></a>`zabbix::resources::userparameters`

This will create resources into puppetdb for automatically configuring agent into zabbix front-end.

#### Parameters

The following parameters are available in the `zabbix::resources::userparameters` defined type:

* [`ensure`](#-zabbix--resources--userparameters--ensure)
* [`hostname`](#-zabbix--resources--userparameters--hostname)
* [`template`](#-zabbix--resources--userparameters--template)

##### <a name="-zabbix--resources--userparameters--ensure"></a>`ensure`

Data type: `Any`

Ensure resource.

##### <a name="-zabbix--resources--userparameters--hostname"></a>`hostname`

Data type: `Any`

Hostname of the machine.

##### <a name="-zabbix--resources--userparameters--template"></a>`template`

Data type: `Any`

Template which should be attached to this host.

### <a name="zabbix--startup"></a>`zabbix::startup`

This manage the zabbix related service startup script.

#### Examples

##### 

```puppet
zabbix::startup { 'agent': }
```

##### 

```puppet
zabbix::startup { 'server': }
```

#### Parameters

The following parameters are available in the `zabbix::startup` defined type:

* [`pidfile`](#-zabbix--startup--pidfile)
* [`agent_configfile_path`](#-zabbix--startup--agent_configfile_path)
* [`server_configfile_path`](#-zabbix--startup--server_configfile_path)
* [`database_type`](#-zabbix--startup--database_type)
* [`zabbix_user`](#-zabbix--startup--zabbix_user)
* [`additional_service_params`](#-zabbix--startup--additional_service_params)
* [`service_type`](#-zabbix--startup--service_type)
* [`manage_database`](#-zabbix--startup--manage_database)
* [`service_name`](#-zabbix--startup--service_name)

##### <a name="-zabbix--startup--pidfile"></a>`pidfile`

Data type: `Optional[Stdlib::Absolutepath]`

Location of the PID file

Default value: `undef`

##### <a name="-zabbix--startup--agent_configfile_path"></a>`agent_configfile_path`

Data type: `Optional[Stdlib::Absolutepath]`

Location of Zabbix's agent configuration file

Default value: `undef`

##### <a name="-zabbix--startup--server_configfile_path"></a>`server_configfile_path`

Data type: `Optional[Stdlib::Absolutepath]`

Location of Zabbix's server configuration file

Default value: `undef`

##### <a name="-zabbix--startup--database_type"></a>`database_type`

Data type: `Optional[Zabbix::Databases]`

Type of database. Can use the following 2 databases:
- postgresql
- mysql

Default value: `undef`

##### <a name="-zabbix--startup--zabbix_user"></a>`zabbix_user`

Data type: `Optional[String]`

User the zabbix service will run as

Default value: `undef`

##### <a name="-zabbix--startup--additional_service_params"></a>`additional_service_params`

Data type: `Optional[String[1]]`

Additional parameters to pass to the service

Default value: `undef`

##### <a name="-zabbix--startup--service_type"></a>`service_type`

Data type: `String`

Systemd service type

Default value: `'simple'`

##### <a name="-zabbix--startup--manage_database"></a>`manage_database`

Data type: `Optional[Boolean]`

When true, it will configure the database and execute the sql scripts.

Default value: `undef`

##### <a name="-zabbix--startup--service_name"></a>`service_name`

Data type: `Optional[String]`

Name of the service. Defaults to the resource name

Default value: `$name`

### <a name="zabbix--template"></a>`zabbix::template`

This will upload an Zabbix Template (XML format)

#### Examples

##### 

```puppet
zabbix::template { 'Template App MySQL':
   templ_source => 'puppet:///modules/zabbix/MySQL.xml'
}
```

#### Parameters

The following parameters are available in the `zabbix::template` defined type:

* [`templ_name`](#-zabbix--template--templ_name)
* [`templ_source`](#-zabbix--template--templ_source)
* [`zabbix_version`](#-zabbix--template--zabbix_version)
* [`delete_missing_applications`](#-zabbix--template--delete_missing_applications)
* [`delete_missing_drules`](#-zabbix--template--delete_missing_drules)
* [`delete_missing_graphs`](#-zabbix--template--delete_missing_graphs)
* [`delete_missing_httptests`](#-zabbix--template--delete_missing_httptests)
* [`delete_missing_items`](#-zabbix--template--delete_missing_items)
* [`delete_missing_templatescreens`](#-zabbix--template--delete_missing_templatescreens)
* [`delete_missing_triggers`](#-zabbix--template--delete_missing_triggers)

##### <a name="-zabbix--template--templ_name"></a>`templ_name`

Data type: `Any`

The name of the template. This name will be found in the Web interface

Default value: `$title`

##### <a name="-zabbix--template--templ_source"></a>`templ_source`

Data type: `Any`

The location of the XML file wich needs to be imported.

Default value: `''`

##### <a name="-zabbix--template--zabbix_version"></a>`zabbix_version`

Data type: `String[1]`

The Zabbix version on which the template will be installed on.

Default value: `$zabbix::params::zabbix_version`

##### <a name="-zabbix--template--delete_missing_applications"></a>`delete_missing_applications`

Data type: `Boolean`

Deletes applications from zabbix that are not in the template when set to true

Default value: `false`

##### <a name="-zabbix--template--delete_missing_drules"></a>`delete_missing_drules`

Data type: `Boolean`

Deletes discovery rules from zabbix that are not in the template when set to true

Default value: `false`

##### <a name="-zabbix--template--delete_missing_graphs"></a>`delete_missing_graphs`

Data type: `Boolean`

Deletes graphs from zabbix that are not in the template when set to true

Default value: `false`

##### <a name="-zabbix--template--delete_missing_httptests"></a>`delete_missing_httptests`

Data type: `Boolean`

Deletes web-scenarios from zabbix that are not in the template when set to true

Default value: `false`

##### <a name="-zabbix--template--delete_missing_items"></a>`delete_missing_items`

Data type: `Boolean`

Deletes items from zabbix that are not in the template when set to true

Default value: `false`

##### <a name="-zabbix--template--delete_missing_templatescreens"></a>`delete_missing_templatescreens`

Data type: `Boolean`

Deletes template-screens from zabbix that are not in the template when set to true

Default value: `false`

##### <a name="-zabbix--template--delete_missing_triggers"></a>`delete_missing_triggers`

Data type: `Boolean`

Deletes triggers from zabbix that are not in the template when set to true

Default value: `false`

### <a name="zabbix--userparameters"></a>`zabbix::userparameters`

This will install an userparameters file with keys for items that can be checked with zabbix.

#### Examples

##### 

```puppet
zabbix::userparameters { 'mysql':
  source => 'puppet:///modules/zabbix/mysqld.conf',
}
```

##### 

```puppet
zabbix::userparameters { 'mysql':
  content => 'UserParameter=mysql.ping,mysqladmin -uroot ping | grep -c alive',
}
```

##### Or when using exported resources (manage_resources is set to true)

```puppet
zabbix::userparameters { 'mysql':
  source   => 'puppet:///modules/zabbix/mysqld.conf',
  template => 'Template App MySQL',
}
```

#### Parameters

The following parameters are available in the `zabbix::userparameters` defined type:

* [`ensure`](#-zabbix--userparameters--ensure)
* [`source`](#-zabbix--userparameters--source)
* [`content`](#-zabbix--userparameters--content)
* [`script`](#-zabbix--userparameters--script)
* [`script_ext`](#-zabbix--userparameters--script_ext)
* [`template`](#-zabbix--userparameters--template)
* [`script_dir`](#-zabbix--userparameters--script_dir)
* [`config_mode`](#-zabbix--userparameters--config_mode)

##### <a name="-zabbix--userparameters--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

If the userparameter should be `present` or `absent`

Default value: `'present'`

##### <a name="-zabbix--userparameters--source"></a>`source`

Data type: `Optional[Stdlib::Filesource]`

File which holds several userparameter entries.

Default value: `undef`

##### <a name="-zabbix--userparameters--content"></a>`content`

Data type: `Optional[String[1]]`

When you have 1 userparameter entry which you want to install.

Default value: `undef`

##### <a name="-zabbix--userparameters--script"></a>`script`

Data type: `Optional[Stdlib::Filesource]`

Low level discovery (LLD) script.

Default value: `undef`

##### <a name="-zabbix--userparameters--script_ext"></a>`script_ext`

Data type: `Optional[String[1]]`

The script extention. Should be started with the dot. Like: .sh .bat .py

Default value: `undef`

##### <a name="-zabbix--userparameters--template"></a>`template`

Data type: `Optional[String[1]]`

When you use exported resources (when manage_resources is set to true on other components)
you'll can add the name of the template which correspondents with the 'content' or
'source' which you add. The template will be added to the host.

Default value: `undef`

##### <a name="-zabbix--userparameters--script_dir"></a>`script_dir`

Data type: `Stdlib::Absolutepath`

When 'script' is used, this parameter can provide the directly where this script needs to be placed. Default: '/usr/bin'

Default value: `'/usr/bin'`

##### <a name="-zabbix--userparameters--config_mode"></a>`config_mode`

Data type: `Stdlib::Filemode`

When 'config_mode' is used, this parameter can provide the mode of the config file who will be created
to keep some credidentials private. Default: '0644'

Default value: `'0644'`

## Resource types

### <a name="zabbix_application"></a>`zabbix_application`

Manage zabbix applications

Example:
  zabbix_application{"app1":
    ensure   => present,
    template => 'template1',
  }
It Raise exception on deleting an application which is a part of used template.

#### Properties

The following properties are available in the `zabbix_application` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `zabbix_application` type.

* [`name`](#-zabbix_application--name)
* [`provider`](#-zabbix_application--provider)
* [`template`](#-zabbix_application--template)

##### <a name="-zabbix_application--name"></a>`name`

namevar

application name

##### <a name="-zabbix_application--provider"></a>`provider`

The specific backend to use for this `zabbix_application` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-zabbix_application--template"></a>`template`

template to which the application is linked

### <a name="zabbix_host"></a>`zabbix_host`

Manage zabbix hosts

#### Properties

The following properties are available in the `zabbix_host` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `groups`

An array of groups the host belongs to.

##### `id`

Internally used hostid

##### `interfacedetails`

Additional interface details.

##### `interfaceid`

Internally used identifier for the host interface

##### `interfacetype`

Interface type. 1 for zabbix agent.

##### `ipaddress`

The IP address of the machine running zabbix agent.

##### `macros`

Array of hashes (macros) which should be loaded for this host.

##### `port`

The port that the zabbix agent is listening on.

##### `proxy`

Whether it is monitored by an proxy or not.

##### `templates`

List of templates which should be loaded for this host.

##### `tls_accept`

How the client connect to the server (unencrypted, psk or cert)

##### `tls_connect`

How the server connect to the client (unencrypted, psk or cert)

##### `tls_issuer`

Certificate issuer.

##### `tls_subject`

Certificate subject.

##### `use_ip`

Valid values: `true`, `false`

Using ipadress instead of dns to connect.

#### Parameters

The following parameters are available in the `zabbix_host` type.

* [`group_create`](#-zabbix_host--group_create)
* [`hostname`](#-zabbix_host--hostname)
* [`provider`](#-zabbix_host--provider)

##### <a name="-zabbix_host--group_create"></a>`group_create`

Valid values: `true`, `false`

Create hostgroup if missing.

##### <a name="-zabbix_host--hostname"></a>`hostname`

FQDN of the machine.

##### <a name="-zabbix_host--provider"></a>`provider`

The specific backend to use for this `zabbix_host` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="zabbix_hostgroup"></a>`zabbix_hostgroup`

Manage zabbix hostgroups

#### Properties

The following properties are available in the `zabbix_hostgroup` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `zabbix_hostgroup` type.

* [`name`](#-zabbix_hostgroup--name)
* [`provider`](#-zabbix_hostgroup--provider)

##### <a name="-zabbix_hostgroup--name"></a>`name`

namevar

hostgroup name

##### <a name="-zabbix_hostgroup--provider"></a>`provider`

The specific backend to use for this `zabbix_hostgroup` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="zabbix_proxy"></a>`zabbix_proxy`

Manage zabbix proxies

#### Properties

The following properties are available in the `zabbix_proxy` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `interfaceid`

(readonly) ID of the interface

##### `ipaddress`

The IP address of the machine running zabbix proxy.

##### `mode`

Valid values: `active`, `passive`, `0`, `1`, `0`, `1`

The kind of mode the proxy running. Active (0) or passive (1).

##### `port`

The port that the zabbix proxy is listening on.

##### `proxyid`

(readonly) ID of the proxy

##### `use_ip`

Using ipadress instead of dns to connect. Is used by the zabbix-api command.

#### Parameters

The following parameters are available in the `zabbix_proxy` type.

* [`hostname`](#-zabbix_proxy--hostname)
* [`provider`](#-zabbix_proxy--provider)

##### <a name="-zabbix_proxy--hostname"></a>`hostname`

FQDN of the proxy.

##### <a name="-zabbix_proxy--provider"></a>`provider`

The specific backend to use for this `zabbix_proxy` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="zabbix_template"></a>`zabbix_template`

Manage zabbix templates

#### Properties

The following properties are available in the `zabbix_template` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `zabbix_template` type.

* [`delete_missing_applications`](#-zabbix_template--delete_missing_applications)
* [`delete_missing_drules`](#-zabbix_template--delete_missing_drules)
* [`delete_missing_graphs`](#-zabbix_template--delete_missing_graphs)
* [`delete_missing_httptests`](#-zabbix_template--delete_missing_httptests)
* [`delete_missing_items`](#-zabbix_template--delete_missing_items)
* [`delete_missing_templatescreens`](#-zabbix_template--delete_missing_templatescreens)
* [`delete_missing_triggers`](#-zabbix_template--delete_missing_triggers)
* [`provider`](#-zabbix_template--provider)
* [`template_name`](#-zabbix_template--template_name)
* [`template_source`](#-zabbix_template--template_source)
* [`zabbix_version`](#-zabbix_template--zabbix_version)

##### <a name="-zabbix_template--delete_missing_applications"></a>`delete_missing_applications`

Delete applications from zabbix which are not in the template.

##### <a name="-zabbix_template--delete_missing_drules"></a>`delete_missing_drules`

Delete discovery rules from zabbix which are not in the template.

##### <a name="-zabbix_template--delete_missing_graphs"></a>`delete_missing_graphs`

Delete graphs from zabbix which are not in the template.

##### <a name="-zabbix_template--delete_missing_httptests"></a>`delete_missing_httptests`

Delete web scenarios from zabbix which are not in the template.

##### <a name="-zabbix_template--delete_missing_items"></a>`delete_missing_items`

Delete items from zabbix which are not in the template.

##### <a name="-zabbix_template--delete_missing_templatescreens"></a>`delete_missing_templatescreens`

Delete templateScreens from zabbix which are not in the template.

##### <a name="-zabbix_template--delete_missing_triggers"></a>`delete_missing_triggers`

Delete triggers from zabbix which are not in the template.

##### <a name="-zabbix_template--provider"></a>`provider`

The specific backend to use for this `zabbix_template` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-zabbix_template--template_name"></a>`template_name`

The name of template.

##### <a name="-zabbix_template--template_source"></a>`template_source`

Template source file.

##### <a name="-zabbix_template--zabbix_version"></a>`zabbix_version`

Zabbix version that the template will be installed on.

### <a name="zabbix_template_host"></a>`zabbix_template_host`

Link or Unlink template to host. Only for Zabbix < 6.0!

Example:
  zabbix_template_host{ 'mysql_template@db1':
    ensure => present,
  }
Name should be in the format of "template_name@hostname"

#### Properties

The following properties are available in the `zabbix_template_host` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `zabbix_template_host` type.

* [`name`](#-zabbix_template_host--name)
* [`provider`](#-zabbix_template_host--provider)

##### <a name="-zabbix_template_host--name"></a>`name`

Valid values: `%r{.+@.+}`

namevar

template_name@host_name

##### <a name="-zabbix_template_host--provider"></a>`provider`

The specific backend to use for this `zabbix_template_host` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

### <a name="zabbix_userparameters"></a>`zabbix_userparameters`

Manage zabbix user templates

#### Properties

The following properties are available in the `zabbix_userparameters` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `zabbix_userparameters` type.

* [`hostname`](#-zabbix_userparameters--hostname)
* [`name`](#-zabbix_userparameters--name)
* [`provider`](#-zabbix_userparameters--provider)
* [`template`](#-zabbix_userparameters--template)

##### <a name="-zabbix_userparameters--hostname"></a>`hostname`

FQDN of the machine.

##### <a name="-zabbix_userparameters--name"></a>`name`

namevar

An unique name for this define.

##### <a name="-zabbix_userparameters--provider"></a>`provider`

The specific backend to use for this `zabbix_userparameters` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="-zabbix_userparameters--template"></a>`template`

Template which should be loaded for this host.

## Data types

### <a name="Zabbix--Databases"></a>`Zabbix::Databases`

Type for supported databases by the zabbix module

Alias of `Enum['postgresql', 'mysql', 'sqlite']`

### <a name="Zabbix--Historyics"></a>`Zabbix::Historyics`

Type for size values in bytes (also allows k/K and m/M as appendix)

Alias of `Optional[Pattern[/^\d+[k|K|m|M]?$/]]`

